@@ -12,16 +12,16 @@
  * Gets the current track from iTunes in a string formated as:
  * TITLE - ARTIST, or NULL if iTunes is closed or stopped.
  */
-const char* getCurrentTrackFromiTunes();
+const char* getCurrentTrackFromiTunes(int);
 
 /**
  * Gets the current track from Spotify in a string formated as:
  * TITLE - ARTIST, or NULL if Spotify is closed or stopped.
  */
-const char* getCurrentTrackFromSpotify();
+const char* getCurrentTrackFromSpotify(int);
 
 /**
  * Gets the current track from VOX in a string formated as:
  * TITLE - ARTIST, or NULL if VOX is closed or stopped.
  */
-const char* getCurrentTrackFromVOX();
+const char* getCurrentTrackFromVOX(int);
