@@ -11,7 +11,7 @@
 #import <Spotify.h>
 #import <VOX.h>
 
-const char* getCurrentTrackFromiTunes() {
+const char* getCurrentTrackFromiTunes(int artist_title_order) {
     NSProcessInfo *pInfo = [NSProcessInfo processInfo];
     NSOperatingSystemVersion version = [pInfo operatingSystemVersion];
     
@@ -24,7 +24,13 @@ const char* getCurrentTrackFromiTunes() {
     
     if([iTunes isRunning]) {
         if([iTunes playerState] != iTunesEPlSStopped) {
-            NSString* track = [NSString stringWithFormat:@"%@ - %@", [[iTunes currentTrack] name], [[iTunes currentTrack] artist]];
+            NSString* track;
+            if(artist_title_order == 0) {
+                track = [NSString stringWithFormat:@"%@ - %@", [[iTunes currentTrack] artist], [[iTunes currentTrack] name]];
+            }
+            else {
+                track = [NSString stringWithFormat:@"%@ - %@", [[iTunes currentTrack] name], [[iTunes currentTrack] artist]];
+            }
             ret = (char*) malloc([track lengthOfBytesUsingEncoding:NSUTF8StringEncoding] + 1);
             [track getCString:ret maxLength:([track lengthOfBytesUsingEncoding:NSUTF8StringEncoding] + 1) encoding:NSUTF8StringEncoding];
         }
@@ -33,12 +39,18 @@ const char* getCurrentTrackFromiTunes() {
     return ret;
 }
 
-const char* getCurrentTrackFromSpotify() {
+const char* getCurrentTrackFromSpotify(int artist_title_order) {
     char* ret = NULL;
     SpotifyApplication *spotify = [SBApplication applicationWithBundleIdentifier:@"com.spotify.client"];
     if([spotify isRunning]) {
         if([spotify playerState] != SpotifyEPlSStopped) {
-            NSString* track = [NSString stringWithFormat:@"%@ - %@", [[spotify currentTrack] name], [[spotify currentTrack] artist]];
+            NSString* track;
+            if(artist_title_order == 0) {
+                track = [NSString stringWithFormat:@"%@ - %@", [[spotify currentTrack] artist], [[spotify currentTrack] name]];
+            }
+            else {
+                track = [NSString stringWithFormat:@"%@ - %@", [[spotify currentTrack] name], [[spotify currentTrack] artist]];
+            }
             ret = (char*) malloc([track lengthOfBytesUsingEncoding:NSUTF8StringEncoding] + 1);
             [track getCString:ret maxLength:([track lengthOfBytesUsingEncoding:NSUTF8StringEncoding] + 1) encoding:NSUTF8StringEncoding];
         }
@@ -47,12 +59,18 @@ const char* getCurrentTrackFromSpotify() {
     return ret;
 }
 
-const char* getCurrentTrackFromVOX() {
+const char* getCurrentTrackFromVOX(int artist_title_order) {
     char* ret = NULL;
     VOXApplication *vox = [SBApplication applicationWithBundleIdentifier:@"com.coppertino.Vox"];
     if([vox isRunning]) {
         if([vox playerState]) {
-            NSString* track = [NSString stringWithFormat:@"%@ - %@", [vox track], [vox artist]];
+            NSString* track;
+            if(artist_title_order == 0) {
+                track = [NSString stringWithFormat:@"%@ - %@", [vox artist], [vox track]];
+            }
+            else {
+                track = [NSString stringWithFormat:@"%@ - %@", [vox track], [vox artist]];
+            }
             ret = (char*) malloc([track lengthOfBytesUsingEncoding:NSUTF8StringEncoding] + 1);
             [track getCString:ret maxLength:([track lengthOfBytesUsingEncoding:NSUTF8StringEncoding] + 1) encoding:NSUTF8StringEncoding];
         }
@@ -61,7 +79,7 @@ const char* getCurrentTrackFromVOX() {
     return ret;
 }
 
-typedef const char* (*currentTrackFunction)(void);
+typedef const char* (*currentTrackFunction)(int);
 currentTrackFunction getCurrentTrackFunctionFromId(int i) {
     switch(i) {
         case 0: return &getCurrentTrackFromiTunes;
