@@ -28,7 +28,6 @@ void button_cfg_cb(void);
 void button_info_cb(void);
 void button_record_cb(void);
 void button_connect_cb(void);
-void choice_cfg_dev_cb(void);
 void button_disconnect_cb(void);
 void button_add_icy_add_cb(void);
 void button_cfg_del_srv_cb(void);
@@ -66,6 +65,10 @@ void input_cfg_present_level_cb(void);
 void input_cfg_absent_level_cb(void);
 void choice_cfg_resample_mode_cb(void);
 void button_cfg_check_for_updates_cb(void);
+void choice_cfg_dev_cb(void);
+void button_cfg_rescan_devices_cb(void);
+void radio_cfg_ID_cb(void);
+void radio_cfg_name_cb(void);
 void choice_cfg_right_channel_cb(void);
 void choice_cfg_left_channel_cb(void);
 
@@ -74,8 +77,17 @@ void button_add_srv_save_cb(void);
 void button_add_srv_show_pwd_cb(void);
 void radio_add_srv_shoutcast_cb(void);
 void radio_add_srv_icecast_cb(void);
+void radio_add_srv_radioco_cb(void);
 void button_add_srv_revoke_cert_cb(void);
+void button_add_srv_get_stations_cb(void);
+void button_add_srv_select_all_cb(void);
+void button_add_srv_deselect_all_cb(void);
+
+void button_start_agent_cb(void);
+void button_stop_agent_cb(void);
 void check_update_at_startup_cb(void);
+void check_start_agent_cb(void);
+void check_minimize_to_tray_cb(void);
 
 void button_rec_browse_cb(void);
 void button_rec_split_now_cb(void);
@@ -114,9 +126,13 @@ void check_gui_ontop_cb(void);
 void check_gui_hide_log_window_cb(void);
 void check_gui_remember_pos_cb(void);
 void check_gui_lcd_auto_cb(void);
+void check_gui_start_minimized_cb(void);
 void button_gui_bg_color_cb(void);
 void button_gui_text_color_cb(void);
 void choice_gui_language_cb(void);
+void radio_gui_vu_gradient_cb(void);
+void radio_gui_vu_solid_cb(void);
+
 
 void slider_gain_cb(void);
 
@@ -126,8 +142,14 @@ void slider_equalizer2_cb(double);
 void slider_equalizer3_cb(double);
 void slider_equalizer4_cb(double);
 void slider_equalizer5_cb(double);
+void slider_equalizer6_cb(double);
+void slider_equalizer7_cb(double);
+void slider_equalizer8_cb(double);
+void slider_equalizer9_cb(double);
+void slider_equalizer10_cb(double);
 
 void check_activate_drc_cb(void);
+void check_aggressive_mode_cb(void);
 void slider_threshold_cb(double);
 void slider_ratio_cb(double);
 void slider_attack_cb(double);
@@ -142,17 +164,63 @@ void check_cfg_rec_hourly_cb(void);
 void check_cfg_connect_cb(void);
 void check_cfg_force_reconnecting_cb(void);
 
-
 void lcd_rotate(void*);
 void ILM216_cb(void);
 void window_main_close_cb(void);
 
 void check_cfg_use_app_cb(void);
 void choice_cfg_app_cb(void);
+void radio_cfg_artist_title_cb(void);
+void radio_cfg_title_artist_cb(void);
 
-void update_song(int called_from_connect_cb);
+void choice_cfg_song_delay_cb(void);
+
+
+void update_song(void* user_data);
 bool stop_recording(bool ask);
 
+void choice_stream_mp3_enc_quality_cb(void);
+void choice_stream_mp3_stereo_mode_cb(void);
+void choice_stream_mp3_bitrate_mode_cb(void);
+void choice_stream_mp3_vbr_quality_cb(void);
+void choice_stream_mp3_vbr_min_bitrate_cb(void);
+void choice_stream_mp3_vbr_max_bitrate_cb(void);
+
+void choice_stream_vorbis_bitrate_mode_cb(void);
+void choice_stream_vorbis_vbr_quality_cb(void);
+void choice_stream_vorbis_vbr_min_bitrate_cb(void);
+void choice_stream_vorbis_vbr_max_bitrate_cb(void);
+
+void choice_stream_opus_audio_type_cb(void);
+void choice_stream_opus_bitrate_mode_cb(void);
+void choice_stream_opus_quality_cb(void);
+void choice_stream_opus_bandwidth_cb(void);
+
+void choice_stream_aac_profile_cb(void);
+void choice_stream_aac_afterburner_cb(void);
+void choice_stream_aac_bitrate_mode_cb(void);
+
+
+void choice_rec_mp3_enc_quality_cb(void);
+void choice_rec_mp3_stereo_mode_cb(void);
+void choice_rec_mp3_bitrate_mode_cb(void);
+void choice_rec_mp3_vbr_quality_cb(void);
+void choice_rec_mp3_vbr_min_bitrate_cb(void);
+void choice_rec_mp3_vbr_max_bitrate_cb(void);
+
+void choice_rec_vorbis_bitrate_mode_cb(void);
+void choice_rec_vorbis_vbr_quality_cb(void);
+void choice_rec_vorbis_vbr_min_bitrate_cb(void);
+void choice_rec_vorbis_vbr_max_bitrate_cb(void);
+
+void choice_rec_opus_audio_type_cb(void);
+void choice_rec_opus_bitrate_mode_cb(void);
+void choice_rec_opus_quality_cb(void);
+void choice_rec_opus_bandwidth_cb(void);
+
+void choice_rec_aac_profile_cb(void);
+void choice_rec_aac_afterburner_cb(void);
+void choice_rec_aac_bitrate_mode_cb(void);
 
 
 
