@@ -39,12 +39,34 @@
 #include "strfuncs.h"
 
 
+int get_bitrate_index(int bitrate)
+{
+    int bitrate_idx[] = { 8, 16, 24, 32, 40, 48, 56, 64, 80, 96, 112,
+                        128, 160, 192, 224, 256, 320 };
+
+    for(int i = 0; i < sizeof(bitrate_idx)/sizeof(int); i++)
+        if(bitrate == bitrate_idx[i])
+            return i;
+
+    return 0;
+}
+
+int get_bitrate_index_vorbis_vbr(int bitrate)
+{
+    int bitrate_idx[] = { 0, 48, 56, 64, 80, 96, 112,
+                        128, 160, 192, 224, 256, 320 };
+
+    for(int i = 0; i < sizeof(bitrate_idx)/sizeof(int); i++)
+        if(bitrate == bitrate_idx[i])
+            return i;
+
+    return 0;
+}
+
 void fill_cfg_widgets(void)
 {
     int i;
 
-    int bitrate[] = { 8, 16, 24, 32, 40, 48, 56, 64, 80, 96, 112,
-                    128, 160, 192, 224, 256, 320, 0 };
 
 #ifndef HAVE_LIBFDK_AAC
     fl_g->menu_item_cfg_aac->hide();
@@ -54,9 +76,18 @@ void fill_cfg_widgets(void)
   
     //fill the main section
     for(i = 0; i < cfg.audio.dev_count; i++)
-        fl_g->choice_cfg_dev->add(cfg.audio.pcm_list[i]->name);
+    {
+        unsigned long dev_name_len = strlen(cfg.audio.pcm_list[i]->name)+10;
+        char *dev_name = (char*)malloc(dev_name_len);
+        
+        snprintf(dev_name, dev_name_len, "%d: %s", i, cfg.audio.pcm_list[i]->name);
+        fl_g->choice_cfg_dev->add(dev_name);
+        free(dev_name);
+    }
 
+    
     fl_g->choice_cfg_dev->value(cfg.audio.dev_num);
+    
 
     fl_g->choice_cfg_act_srv->clear();
     fl_g->choice_cfg_act_srv->redraw();
@@ -105,6 +136,10 @@ void fill_cfg_widgets(void)
     fl_g->input_log_filename->value(cfg.main.log_file);
 
     fl_g->check_update_at_startup->value(cfg.main.check_for_update);
+    
+    fl_g->check_start_agent->value(cfg.main.start_agent);
+    fl_g->check_minimize_to_tray->value(cfg.main.minimize_to_tray);
+
 
     //fill the audio section
     if(!strcmp(cfg.audio.codec, "mp3"))
@@ -119,22 +154,19 @@ void fill_cfg_widgets(void)
     {
         fl_g->choice_cfg_codec->value(CHOICE_FLAC);
         fl_g->choice_cfg_bitrate->hide();
-
     }
     
+    if (cfg.audio.dev_remember == REMEMBER_BY_ID)
+        fl_g->radio_cfg_ID->setonly();
+    else
+        fl_g->radio_cfg_name->setonly();
+
     if(cfg.audio.channel == 1)
         fl_g->choice_cfg_channel->value(CHOICE_MONO);
     else
         fl_g->choice_cfg_channel->value(CHOICE_STEREO);
 
-    for(i = 0; bitrate[i] != 0; i++)
-    {
-        if(cfg.audio.bitrate == bitrate[i])
-        {
-            fl_g->choice_cfg_bitrate->value(i);
-            break;
-        }
-    }
+    fl_g->choice_cfg_bitrate->value(get_bitrate_index(cfg.audio.bitrate));
 
     fl_g->input_cfg_present_level->value(-cfg.audio.signal_level);
     fl_g->input_cfg_absent_level->value(-cfg.audio.silence_level);
@@ -148,7 +180,8 @@ void fill_cfg_widgets(void)
     // Fill stream section
     fl_g->check_song_update_active->value(cfg.main.song_update);
     fl_g->check_read_last_line->value(cfg.main.read_last_line);
-
+    fl_g->choice_cfg_song_delay->value(cfg.main.song_delay/2);
+    
     fl_g->input_cfg_song_file->value(cfg.main.song_path);
     fl_g->input_cfg_signal->value(cfg.main.signal_threshold);
     fl_g->input_cfg_silence->value(cfg.main.silence_threshold);
@@ -163,6 +196,10 @@ void fill_cfg_widgets(void)
     fl_g->choice_cfg_app->add("VOX");
     fl_g->check_cfg_use_app->value(cfg.main.app_update);
     fl_g->choice_cfg_app->value(cfg.main.app_update_service);
+    if (cfg.main.app_artist_title_order == APP_ARTIST_FIRST)
+        fl_g->radio_cfg_artist_title->setonly();
+    else
+        fl_g->radio_cfg_title_artist->setonly();
 #elif (__linux__ || __FreeBSD__) && HAVE_DBUS
     fl_g->choice_cfg_app->add("Rhythmbox");
     fl_g->choice_cfg_app->add("Banshee");
@@ -172,12 +209,18 @@ void fill_cfg_widgets(void)
     fl_g->choice_cfg_app->add("Strawberry");
     fl_g->check_cfg_use_app->value(cfg.main.app_update);
     fl_g->choice_cfg_app->value(cfg.main.app_update_service);
+    if (cfg.main.app_artist_title_order == APP_ARTIST_FIRST)
+        fl_g->radio_cfg_artist_title->setonly();
+    else
+        fl_g->radio_cfg_title_artist->setonly();
 #elif WIN32
     fl_g->choice_cfg_app->add(_("Not supported on Windows"));
     fl_g->choice_cfg_app->value(0);
     fl_g->check_cfg_use_app->value(0);
     fl_g->check_cfg_use_app->deactivate();
     fl_g->choice_cfg_app->deactivate();
+    fl_g->radio_cfg_artist_title->deactivate();
+    fl_g->radio_cfg_title_artist->deactivate();
 #endif
     
     
@@ -206,9 +249,7 @@ void fill_cfg_widgets(void)
         fl_g->choice_rec_bitrate->hide();
     }
 
-    for(i = 0; bitrate[i] != 0; i++)
-        if(cfg.rec.bitrate == bitrate[i])
-            fl_g->choice_rec_bitrate->value(i);
+    fl_g->choice_rec_bitrate->value(get_bitrate_index(cfg.rec.bitrate));
 
     if(cfg.rec.start_rec)
         fl_g->check_cfg_auto_start_rec->value(1);
@@ -259,8 +300,24 @@ void fill_cfg_widgets(void)
     
     slider_equalizer5_cb(cfg.dsp.gain5);
     fl_g->equalizerSlider5->value(cfg.dsp.gain5);
+    
+    slider_equalizer6_cb(cfg.dsp.gain6);
+    fl_g->equalizerSlider6->value(cfg.dsp.gain6);
+    
+    slider_equalizer7_cb(cfg.dsp.gain7);
+    fl_g->equalizerSlider7->value(cfg.dsp.gain7);
+    
+    slider_equalizer8_cb(cfg.dsp.gain8);
+    fl_g->equalizerSlider8->value(cfg.dsp.gain8);
+    
+    slider_equalizer9_cb(cfg.dsp.gain9);
+    fl_g->equalizerSlider9->value(cfg.dsp.gain9);
+    
+    slider_equalizer10_cb(cfg.dsp.gain10);
+    fl_g->equalizerSlider10->value(cfg.dsp.gain10);
 	
 	fl_g->check_activate_drc->value(cfg.dsp.compressor);
+    fl_g->check_aggressive_mode->value(cfg.dsp.aggressive_mode);
 	
 	slider_threshold_cb(cfg.dsp.threshold);
     fl_g->thresholdSlider->value(cfg.dsp.threshold);
@@ -278,10 +335,8 @@ void fill_cfg_widgets(void)
     fl_g->makeupSlider->value(cfg.dsp.makeup_gain);
 	
     //fill the GUI section
-    fl_g->button_gui_bg_color->color(cfg.main.bg_color,
-            fl_lighter((Fl_Color)cfg.main.bg_color));
-    fl_g->button_gui_text_color->color(cfg.main.txt_color,
-            fl_lighter((Fl_Color)cfg.main.txt_color));
+    fl_g->button_gui_bg_color->color(cfg.main.bg_color, fl_lighter((Fl_Color)cfg.main.bg_color));
+    fl_g->button_gui_text_color->color(cfg.main.txt_color,fl_lighter((Fl_Color)cfg.main.txt_color));
     fl_g->check_gui_attach->value(cfg.gui.attach);
     fl_g->check_gui_ontop->value(cfg.gui.ontop);
     if(cfg.gui.ontop)
@@ -294,8 +349,65 @@ void fill_cfg_widgets(void)
 
    
     fl_g->check_gui_lcd_auto->value(cfg.gui.lcd_auto);
+
+    fl_g->check_gui_start_minimized->value(cfg.gui.start_minimized);
+
     
     fl_g->choice_gui_language->value(cfg.gui.lang);
+    
+    if (cfg.gui.vu_mode == VU_MODE_GRADIENT)
+        fl_g->radio_gui_vu_gradient->setonly();
+    else
+        fl_g->radio_gui_vu_solid->setonly();
+
+
+    //fill mp3 codec settings section
+    fl_g->choice_stream_mp3_enc_quality->value(cfg.mp3_codec_stream.enc_quality);
+    fl_g->choice_stream_mp3_stereo_mode->value(cfg.mp3_codec_stream.stereo_mode);
+    fl_g->choice_stream_mp3_bitrate_mode->value(cfg.mp3_codec_stream.bitrate_mode);
+    fl_g->choice_stream_mp3_vbr_quality->value(cfg.mp3_codec_stream.vbr_quality);
+    fl_g->choice_stream_mp3_vbr_min_bitrate->value(get_bitrate_index(cfg.mp3_codec_stream.vbr_min_bitrate));
+    fl_g->choice_stream_mp3_vbr_max_bitrate->value(get_bitrate_index(cfg.mp3_codec_stream.vbr_max_bitrate));
+
+    fl_g->choice_rec_mp3_enc_quality->value(cfg.mp3_codec_rec.enc_quality);
+    fl_g->choice_rec_mp3_stereo_mode->value(cfg.mp3_codec_rec.stereo_mode);
+    fl_g->choice_rec_mp3_bitrate_mode->value(cfg.mp3_codec_rec.bitrate_mode);
+    fl_g->choice_rec_mp3_vbr_quality->value(cfg.mp3_codec_rec.vbr_quality);
+    fl_g->choice_rec_mp3_vbr_min_bitrate->value(get_bitrate_index(cfg.mp3_codec_rec.vbr_min_bitrate));
+    fl_g->choice_rec_mp3_vbr_max_bitrate->value(get_bitrate_index(cfg.mp3_codec_rec.vbr_max_bitrate));
+
+
+    //fill vorbis codec settings section
+    fl_g->choice_stream_vorbis_bitrate_mode->value(cfg.vorbis_codec_stream.bitrate_mode);
+    fl_g->choice_stream_vorbis_vbr_quality->value(cfg.vorbis_codec_stream.vbr_quality);
+    fl_g->choice_stream_vorbis_vbr_min_bitrate->value(get_bitrate_index_vorbis_vbr(cfg.vorbis_codec_stream.vbr_min_bitrate));
+    fl_g->choice_stream_vorbis_vbr_max_bitrate->value(get_bitrate_index_vorbis_vbr(cfg.vorbis_codec_stream.vbr_max_bitrate));
+
+    fl_g->choice_rec_vorbis_bitrate_mode->value(cfg.vorbis_codec_rec.bitrate_mode);
+    fl_g->choice_rec_vorbis_vbr_quality->value(cfg.vorbis_codec_rec.vbr_quality);
+    fl_g->choice_rec_vorbis_vbr_min_bitrate->value(get_bitrate_index_vorbis_vbr(cfg.vorbis_codec_rec.vbr_min_bitrate));
+    fl_g->choice_rec_vorbis_vbr_max_bitrate->value(get_bitrate_index_vorbis_vbr(cfg.vorbis_codec_rec.vbr_max_bitrate));
+    
+    //fill opus codec settings section
+    fl_g->choice_stream_opus_bitrate_mode->value(cfg.opus_codec_stream.bitrate_mode);
+    fl_g->choice_stream_opus_quality->value(cfg.opus_codec_stream.quality);
+    fl_g->choice_stream_opus_audio_type->value(cfg.opus_codec_stream.audio_type);
+    fl_g->choice_stream_opus_bandwidth->value(cfg.opus_codec_stream.bandwidth);
+
+    fl_g->choice_rec_opus_bitrate_mode->value(cfg.opus_codec_rec.bitrate_mode);
+    fl_g->choice_rec_opus_quality->value(cfg.opus_codec_rec.quality);
+    fl_g->choice_rec_opus_audio_type->value(cfg.opus_codec_rec.audio_type);
+    fl_g->choice_rec_opus_bandwidth->value(cfg.opus_codec_rec.bandwidth);
+    
+
+    //fill aac codec settings section
+    fl_g->choice_stream_aac_bitrate_mode->value(cfg.aac_codec_stream.bitrate_mode);
+    fl_g->choice_stream_aac_afterburner->value(cfg.aac_codec_stream.afterburner);
+    fl_g->choice_stream_aac_profile->value(cfg.aac_codec_stream.profile);
+
+    fl_g->choice_rec_aac_bitrate_mode->value(cfg.aac_codec_rec.bitrate_mode);
+    fl_g->choice_rec_aac_afterburner->value(cfg.aac_codec_rec.afterburner);
+    fl_g->choice_rec_aac_profile->value(cfg.aac_codec_rec.profile);
 
 }
 
@@ -330,10 +442,9 @@ void update_channel_lists(void)
 {
     
     int i;
-    char ch_num_txt[8];
+    char ch_num_txt[16];
     
     int dev_num = fl_g->choice_cfg_dev->value();
-    char* dev_name = cfg.audio.pcm_list[dev_num]->name;
     int num_of_channels = cfg.audio.pcm_list[dev_num]->num_of_channels;
     
     fl_g->choice_cfg_left_channel->clear();
@@ -351,6 +462,22 @@ void update_channel_lists(void)
     
 }
 
+void write_log(const char* message)
+{
+    FILE *log_fd;
+
+    if ((cfg.main.log_file != NULL) && (strlen(cfg.main.log_file) > 0))
+    {
+        log_fd = fl_fopen(cfg.main.log_file, "ab");
+        if (log_fd != NULL)
+        {
+            fprintf(log_fd, "%s", message);
+            fclose(log_fd);
+        }
+    }
+        
+}
+
 void print_info(const char* info, int info_type)
 {
     char timebuf[10];
@@ -399,15 +526,22 @@ void print_info(const char* info, int info_type)
 
             strrpl(&infotxt, (char*)":,", (char*)": ", MODE_ALL);
             strrpl(&infotxt, (char*)"\t", (char*)"", MODE_ALL);
-
-            len = strlen(infotxt)-1;
-            // remove trailing commas and spaces 
-            while (infotxt[len] == ',' || infotxt[len] == ' ')
+            
+            
+            len = int(strlen(infotxt))-1;
+            
+            if (len > 0)
             {
-                infotxt[len--] = '\0';
+                // remove trailing commas and spaces
+                while (infotxt[len] == ',' || infotxt[len] == ' ')
+                {
+                    infotxt[len--] = '\0';
+                    if (len < 0)
+                        break;
+                }
+                
+                fprintf(log_fd, "%s %s\n", logtimestamp, infotxt);
             }
-
-            fprintf(log_fd, "%s %s\n", logtimestamp, infotxt);
             fclose(log_fd);
         }
 
@@ -418,6 +552,11 @@ void print_info(const char* info, int info_type)
 
 void print_lcd(const char *text, int len, int home, int clear)
 {
+    if (!strcmp(text, _("idle")))
+        fl_g->radio_co_logo->show();
+    else
+        fl_g->radio_co_logo->hide();
+    
     if(clear)
         fl_g->lcd->clear();
 
@@ -430,26 +569,27 @@ void print_lcd(const char *text, int len, int home, int clear)
 
 void expand_string(char **str)
 {
-    char m[3], d[3], y[5], hh[3], mi[3], ss[3];
+    int str_len;
+    char expanded_str[1024];
     struct tm *date;
     const time_t t = time(NULL);
 
-    date = localtime(&t);
-
-    snprintf(ss,  3, "%02d", date->tm_sec);
-    snprintf(mi,  3, "%02d", date->tm_min);
-    snprintf(hh,  3, "%02d", date->tm_hour);
-    snprintf(d,   3, "%02d", date->tm_mday);
-    snprintf(m,   3, "%02d", date->tm_mon+1);
-    snprintf(y,   5, "%d",   date->tm_year+1900);
+    // The %i (index number) place holder must be replaced with %%i
+    // Otherwise strftime will replace %i with i and the index number will loose its function
+    strrpl(str, (char*)"%i", (char*)"%%i", MODE_ALL);
     
-    strrpl(str, (char*)"%S", ss, MODE_ALL);
-    strrpl(str, (char*)"%M", mi, MODE_ALL);
-    strrpl(str, (char*)"%H", hh, MODE_ALL);
-    strrpl(str, (char*)"%d", d, MODE_ALL);
-    strrpl(str, (char*)"%m", m, MODE_ALL);
-    strrpl(str, (char*)"%y", y, MODE_ALL);
-    strrpl(str, (char*)"%Y", y, MODE_ALL); // %Y and %y both work as year
+    // %c, %x, %X specifiers are not allowed because they return illegal characters for file names
+    // Therefore we make sure that strftime will ignore them
+    strrpl(str, (char*)"%c", (char*)"%%c", MODE_ALL);
+    strrpl(str, (char*)"%x", (char*)"%%x", MODE_ALL);
+    strrpl(str, (char*)"%X", (char*)"%%X", MODE_ALL);
+
+    date = localtime(&t);
+    strftime(expanded_str, sizeof(expanded_str)-1, *str, date);
+    
+    str_len = strlen(expanded_str);
+    *str = (char *)realloc(*str, str_len+1);
+    strncpy(*str, expanded_str, str_len+1);
 }
 
 void test_file_extension(void)
@@ -479,7 +619,32 @@ void test_file_extension(void)
 void init_main_gui_and_audio(void)
 {
     if(cfg.gui.remember_pos)
-        fl_g->window_main->position(cfg.gui.x_pos, cfg.gui.y_pos);
+    {
+        int butt_x, butt_y, butt_w, butt_h;
+
+        butt_x = cfg.gui.x_pos;
+        butt_y = cfg.gui.y_pos;
+        butt_w = fl_g->window_main->w();
+        butt_h = fl_g->window_main->h();
+                
+        int sx, sy, sw, sh;
+        int is_visible = 0;
+        for (int i = 0; i < Fl::screen_count(); i++)
+        {
+            Fl::screen_xywh(sx, sy, sw, sh, i);
+            if ((butt_x >= sx-butt_w+50) && (butt_x+50 < (sx+sw)) && (butt_y >= sy-butt_h+50) && (butt_y+50 < (sy+sh))) {
+                is_visible = 1;
+            }
+        }
+        
+        // Move butt window to the saved position only if at least 50 pixel of butt are visible on the screen
+        if (is_visible)
+            fl_g->window_main->position(cfg.gui.x_pos, cfg.gui.y_pos);
+        
+                
+       // if( (butt_x+butt_w > 50) && (butt_x+50 < total_screen_width) && (butt_y+butt_h > 50) && (butt_y+50 < total_screen_height) )
+    }
+    
     
     fl_g->slider_gain->value(util_factor_to_db(cfg.main.gain));
     fl_g->window_main->redraw();
@@ -495,31 +660,59 @@ void init_main_gui_and_audio(void)
     lame_stream.channel = cfg.audio.channel;
     lame_stream.bitrate = cfg.audio.bitrate;
     lame_stream.samplerate = cfg.audio.samplerate;
+    lame_stream.enc_quality = cfg.mp3_codec_stream.enc_quality;
+    lame_stream.stereo_mode = cfg.mp3_codec_stream.stereo_mode;
+    lame_stream.bitrate_mode = cfg.mp3_codec_stream.bitrate_mode;
+    lame_stream.vbr_quality = cfg.mp3_codec_stream.vbr_quality;
+    lame_stream.vbr_min_bitrate = cfg.mp3_codec_stream.vbr_min_bitrate;
+    lame_stream.vbr_max_bitrate = cfg.mp3_codec_stream.vbr_max_bitrate;
     lame_enc_reinit(&lame_stream);
 
     lame_rec.channel = cfg.audio.channel;
     lame_rec.bitrate = cfg.rec.bitrate;
     lame_rec.samplerate = cfg.audio.samplerate;
+    lame_rec.enc_quality = cfg.mp3_codec_rec.enc_quality;
+    lame_rec.stereo_mode = cfg.mp3_codec_rec.stereo_mode;
+    lame_rec.bitrate_mode = cfg.mp3_codec_rec.bitrate_mode;
+    lame_rec.vbr_quality = cfg.mp3_codec_rec.vbr_quality;
+    lame_rec.vbr_min_bitrate = cfg.mp3_codec_rec.vbr_min_bitrate;
+    lame_rec.vbr_max_bitrate = cfg.mp3_codec_rec.vbr_max_bitrate;
     lame_enc_reinit(&lame_rec);
 
     vorbis_stream.channel = cfg.audio.channel;
     vorbis_stream.bitrate = cfg.audio.bitrate;
     vorbis_stream.samplerate = cfg.audio.samplerate;
+    vorbis_stream.bitrate_mode = cfg.vorbis_codec_stream.bitrate_mode;
+    vorbis_stream.vbr_quality = 1-(cfg.vorbis_codec_stream.vbr_quality*0.1);
+    vorbis_stream.vbr_min_bitrate = cfg.vorbis_codec_stream.vbr_min_bitrate;
+    vorbis_stream.vbr_max_bitrate = cfg.vorbis_codec_stream.vbr_max_bitrate;
     vorbis_enc_reinit(&vorbis_stream);
 
     vorbis_rec.channel = cfg.audio.channel;
     vorbis_rec.bitrate = cfg.rec.bitrate;
     vorbis_rec.samplerate = cfg.audio.samplerate;
+    vorbis_rec.bitrate_mode = cfg.vorbis_codec_rec.bitrate_mode;
+    vorbis_rec.vbr_quality = 1-(cfg.vorbis_codec_rec.vbr_quality*0.1);
+    vorbis_rec.vbr_min_bitrate = cfg.vorbis_codec_rec.vbr_min_bitrate;
+    vorbis_rec.vbr_max_bitrate = cfg.vorbis_codec_rec.vbr_max_bitrate;
     vorbis_enc_reinit(&vorbis_rec);
     
     opus_stream.channel = cfg.audio.channel;
     opus_stream.bitrate = cfg.audio.bitrate*1000;
     opus_stream.samplerate = cfg.audio.samplerate;
+    opus_stream.bitrate_mode = cfg.opus_codec_stream.bitrate_mode;
+    opus_stream.audio_type = cfg.opus_codec_stream.audio_type;
+    opus_stream.quality = cfg.opus_codec_stream.quality;
+    opus_stream.bandwidth = cfg.opus_codec_stream.bandwidth;
     opus_enc_reinit(&opus_stream);
     
     opus_rec.channel = cfg.audio.channel;
     opus_rec.bitrate = cfg.rec.bitrate*1000;
     opus_rec.samplerate = cfg.audio.samplerate;
+    opus_rec.bitrate_mode = cfg.opus_codec_rec.bitrate_mode;
+    opus_rec.audio_type = cfg.opus_codec_rec.audio_type;
+    opus_rec.quality = cfg.opus_codec_rec.quality;
+    opus_rec.bandwidth = cfg.opus_codec_rec.bandwidth;
     opus_enc_reinit(&opus_rec);
 
 #ifdef HAVE_LIBFDK_AAC
@@ -528,13 +721,17 @@ void init_main_gui_and_audio(void)
         aac_stream.channel = cfg.audio.channel;
         aac_stream.bitrate = cfg.audio.bitrate;
         aac_stream.samplerate = cfg.audio.samplerate;
-        aac_stream.aot = cfg.audio.aac_aot;
+        aac_stream.bitrate_mode = cfg.aac_codec_stream.bitrate_mode;
+        aac_stream.profile = cfg.aac_codec_stream.profile;
+        aac_stream.afterburner = cfg.aac_codec_stream.afterburner == 0 ? 1 : 0;
         aac_enc_reinit(&aac_stream);
         
         aac_rec.channel = cfg.audio.channel;
         aac_rec.bitrate = cfg.rec.bitrate;
         aac_rec.samplerate = cfg.audio.samplerate;
-        aac_rec.aot = cfg.audio.aac_aot;
+        aac_rec.bitrate_mode = cfg.aac_codec_rec.bitrate_mode;
+        aac_rec.profile = cfg.aac_codec_rec.profile;
+        aac_rec.afterburner = cfg.aac_codec_rec.afterburner == 0 ? 1 : 0;
         aac_enc_reinit(&aac_rec);
     }
 #endif
