@@ -20,11 +20,16 @@
 #include <signal.h>
 #include <time.h>
 #include <sys/stat.h>
+#include <pthread.h>
 
 #ifndef WIN32
  #include <sys/wait.h>
 #endif
 
+#ifdef WIN32
+ #include "tray_agent.h"
+#endif
+
 #include "gettext.h"
 #include "config.h"
 
@@ -40,12 +45,18 @@
 #include "strfuncs.h"
 #include "fl_timer_funcs.h"
 #include "command.h"
+#ifdef WITH_RADIOCO
+ #include "radioco.h"
+#endif
 
 #if __APPLE__ && __MACH__
  #include "CurrentTrackOSX.h"
 #endif
 
-const char* (*current_track_app)(void);
+const char* (*current_track_app)(int);
+
+void split_recording_file(void);
+pthread_t split_recording_file_thread;
 
 void cmd_timer(void*)
 {
@@ -90,17 +101,59 @@ void cmd_timer(void*)
             stop_recording(false);
             Fl::repeat_timeout(0.25, &cmd_timer);
             break;
+        case CMD_SPLIT_RECORDING:
+            split_recording_file();
+            Fl::repeat_timeout(0.25, &cmd_timer);
+            break;
+        case CMD_QUIT:
+            stop_recording(false);
+            button_disconnect_cb();
+            exit(0);
+            break;
+        case CMD_UPDATE_SONGNAME:
+            cfg.main.song = (char*)realloc(cfg.main.song, command.param_size+1);
+            strcpy(cfg.main.song, (char*)command.param);
+            Fl::add_timeout(cfg.main.song_delay, &update_song);
+            Fl::repeat_timeout(0.25, &cmd_timer);
+            break;
         case CMD_GET_STATUS:
             uint32_t status;
             status = (connected<<STATUS_CONNECTED) | (try_to_connect<<STATUS_CONNECTING) | (recording<<STATUS_RECORDING);
             command_send_status_reply(status);
-
             Fl::repeat_timeout(0.25, &cmd_timer);
+            break;
         default:
             Fl::repeat_timeout(0.25, &cmd_timer);
     }
 }
 
+void agent_watchdog_timer(void*)
+{
+#ifdef WIN32
+    int is_iconfied = fl_g->window_main->shown() && !fl_g->window_main->visible();
+    
+    if (cfg.main.minimize_to_tray == 1 && is_iconfied == 1 && tray_agent_is_running(NULL) == 0)
+        fl_g->window_main->show();
+    else
+        Fl::repeat_timeout(1, &agent_watchdog_timer);
+#endif
+}
+
+void has_agent_been_started_timer(void*)
+{
+#ifdef WIN32
+    if (tray_agent_is_running(NULL) != 1)
+	fl_alert("Agent could not be started.");
+#endif
+}
+
+void has_agent_been_stopped_timer(void*)
+{
+#ifdef WIN32
+    if (tray_agent_is_running(NULL) != 0)
+	fl_alert("Agent could not be stopped.");
+#endif
+}
 
 void vu_meter_timer(void*)
 {
@@ -116,39 +169,39 @@ void display_info_timer(void*)
 
     if(try_to_connect == 1)
     {
-        Fl::repeat_timeout(0.1, &display_info_timer);
+        Fl::repeat_timeout(0.2, &display_info_timer);
         return;
     }
 
     if(display_info == SENT_DATA)
     {
-        sprintf(lcd_text_buf, _("stream sent\n%0.2lfMB"),
+        snprintf(lcd_text_buf, sizeof(lcd_text_buf), _("stream sent\n%0.2lfMB"),
                 kbytes_sent / 1024);
         print_lcd(lcd_text_buf, strlen(lcd_text_buf), 0, 1);
     }
 
     if(display_info == STREAM_TIME && timer_is_elapsed(&stream_timer))
     {
-        sprintf(lcd_text_buf, _("stream time\n%s"),
+        snprintf(lcd_text_buf, sizeof(lcd_text_buf), _("stream time\n%s"),
                 timer_get_time_str(&stream_timer));
         print_lcd(lcd_text_buf, strlen(lcd_text_buf), 0, 1);
     }
 
     if(display_info == REC_TIME && timer_is_elapsed(&rec_timer))
     {
-        sprintf(lcd_text_buf, _("record time\n%s"),
+        snprintf(lcd_text_buf, sizeof(lcd_text_buf), _("record time\n%s"),
                 timer_get_time_str(&rec_timer));
         print_lcd(lcd_text_buf, strlen(lcd_text_buf), 0, 1);
     }
 
     if(display_info == REC_DATA)
     {
-        sprintf(lcd_text_buf, _("record size\n%0.2lfMB"),
+        snprintf(lcd_text_buf, sizeof(lcd_text_buf), _("record size\n%0.2lfMB"),
                 kbytes_written / 1024);
         print_lcd(lcd_text_buf, strlen(lcd_text_buf), 0, 1);
     }
 
-    Fl::repeat_timeout(0.1, &display_info_timer);
+    Fl::repeat_timeout(0.2, &display_info_timer);
 }
 
 void display_rotate_timer(void*) 
@@ -194,10 +247,15 @@ void is_connected_timer(void*)
     if(!connected)
     {
         print_info(_("ERROR: Connection lost\nreconnecting..."), 1);
-        if(cfg.srv[cfg.selected_srv]->type == SHOUTCAST)
-            sc_disconnect();
-        else
+        if(cfg.srv[cfg.selected_srv]->type == ICECAST)
             ic_disconnect();
+        else
+            sc_disconnect();
+
+	
+#ifdef WIN32
+	tray_agent_send_cmd(TA_CONNECT_STATE);
+#endif
 
         Fl::remove_timeout(&display_info_timer);
         Fl::remove_timeout(&is_connected_timer);
@@ -227,35 +285,72 @@ void cfg_win_pos_timer(void*)
     Fl::repeat_timeout(0.1, &cfg_win_pos_timer);
 }
 
-void split_recording_timer(void* mode)
+void *split_recording_file_thread_func(void *init)
+{
+       
+    int synced_to_full_hour;
+    time_t start_time;
+        
+    time_t current_time;
+    struct tm *current_time_tm;
+
+    int split_time_seconds = 60*cfg.rec.split_time;
+    
+    struct timespec wait_400ms;
+    wait_400ms.tv_sec = 0;
+    wait_400ms.tv_nsec = (400*1000*1000);
+    
+    start_time = time(NULL);
+    synced_to_full_hour = 0;
+    
+    set_max_thread_priority();
+    
+    while(record)
+    {
+        current_time = time(NULL);
+        current_time_tm = localtime(&current_time);
+        
+        if((cfg.rec.sync_to_hour == 1)      &&
+           (synced_to_full_hour == 0)       &&
+           (current_time_tm->tm_min == 0)   &&
+           (current_time_tm->tm_sec >= 0))
+        {
+            start_time = current_time-current_time_tm->tm_sec;
+            synced_to_full_hour = 1;
+            split_recording_file();
+        }
+        else if(current_time-start_time >= split_time_seconds)
+        {
+            start_time = current_time;
+            split_recording_file();
+        }
+        
+        nanosleep(&wait_400ms, NULL);
+        
+    }
+    
+    return NULL;
+}
+
+
+
+void split_recording_file_timer(void)
+{
+    pthread_create(&split_recording_file_thread, NULL, split_recording_file_thread_func, NULL);
+}
+
+void split_recording_file(void)
 {
     int i;
-    int button_clicked = 0;
-    static int with_repeat = 0;
     char *insert_pos;
     char *path;
     char *ext;
     char file_num_str[12];
     char *path_for_index_loop;
-    struct tm *local_time;
-    const time_t t = time(NULL);
     
-    if (recording == 0)
+    if (!recording)
         return;
-    
-    if(*((int*)mode) == 1)
-        with_repeat = 1;
-    else
-        button_clicked = 1;
-
-
-    // Values < 0 are not allowed
-    if(fl_g->input_rec_split_time->value() < 0)
-    {
-        fl_g->input_rec_split_time->value(0);
-        return;
-    }
-
+        
     path = strdup(cfg.rec.path_fmt);
     expand_string(&path);
     ext = util_get_file_extension(cfg.rec.filename);
@@ -267,10 +362,8 @@ void split_recording_timer(void* mode)
         return;
     }
 
-
     path_for_index_loop = strdup(path);
 
-
     //check if the file already exists
     if((next_fd = fl_fopen(path, "rb")) != NULL)
     {
@@ -291,7 +384,7 @@ void split_recording_timer(void* mode)
             strinsrt(&path, file_num_str, insert_pos-1);
 
             if((next_fd = fl_fopen(path, "rb")) == NULL)
-                break; // found valid file name 
+                break; // found valid file name
 
             fclose(next_fd);
 
@@ -320,19 +413,6 @@ void split_recording_timer(void* mode)
 
     next_file = 1;
     free(path);
-
-
-    if(with_repeat == 1 && button_clicked == 0)
-    {
-        local_time = localtime(&t);
-
-        // Make sure that the 60 minutes boundary is not violated in case sync_to_hour == 1
-        if((cfg.rec.sync_to_hour == 1) && ((local_time->tm_min + cfg.rec.split_time) > 60))
-            Fl::repeat_timeout(60*(60 - local_time->tm_min), &split_recording_timer, &with_repeat);
-        else
-            Fl::repeat_timeout(60*cfg.rec.split_time, &split_recording_timer, &with_repeat);
-
-    }
 }
 
 void stream_signal_timer(void*)
@@ -382,6 +462,63 @@ void record_signal_timer(void*)
     Fl::repeat_timeout(1, &record_signal_timer);
 }
 
+void wait_for_radioco_timer(void*)
+{
+#ifdef WITH_RADIOCO
+    int error;
+    
+    if (radioco_get_state() == RADIOCO_STATE_WAITING)
+        goto exit;
+        
+    error = radioco_get_thread_error();
+    
+    if (error == RADIOCO_ERR_OK)
+    {
+        error = radioco_request_station_list();
+        if (error == RADIOCO_ERR_OK)
+        {
+            radioco_stations_t stations;
+            radioco_get_station_list(&stations);
+            int nitems = fl_g->browser_add_srv_station_list->nitems();
+            for (int i = 0; i < stations.num_of_stations; i++)
+            {
+                bool exists = false;
+                for (int j = 0; j < nitems; j++) {
+                    char *list_name = fl_g->browser_add_srv_station_list->text(j+1);
+                    if (!strcmp(list_name, stations.name[i])) {
+                        exists = true;
+                        break;
+                    }
+                }
+                
+                if (exists == false)
+                    fl_g->browser_add_srv_station_list->add(stations.name[i], 1);
+            }
+            fl_g->browser_add_srv_station_list->redraw();
+            return;
+        }
+        else
+        {
+            fl_alert("Error during radioco stations request (%d).\nPlease try again.", error);
+            return;
+        }
+    }
+    else if (error == RADIOCO_ERR_CANCELED)
+    {
+        return;
+    }
+    else
+    {
+        fl_alert("Error in radioco thread (%d).\nPlease try again.", error);
+        return;
+    }
+    
+    
+exit:
+    Fl::repeat_timeout(1, &wait_for_radioco_timer);
+#endif
+}
+
 void stream_silence_timer(void*)
 {
     //printf("stream_silence_timer\n");
@@ -542,9 +679,20 @@ void songfile_timer(void* user_data)
 			last_line = song;
         }
         
-        cfg.main.song = (char*) realloc(cfg.main.song, strlen(last_line) +1);
-        strcpy(cfg.main.song, last_line);
-        update_song(0);
+        // Remove UTF-8 BOM
+        if ((uint8_t)last_line[0] == 0xEF && (uint8_t)last_line[1] == 0xBB && (uint8_t)last_line[2] == 0xBF)
+        {
+            cfg.main.song = (char*) realloc(cfg.main.song, strlen(last_line) +1);
+            strcpy(cfg.main.song, last_line+3);
+        }
+        else
+        {
+            cfg.main.song = (char*) realloc(cfg.main.song, strlen(last_line) +1);
+            strcpy(cfg.main.song, last_line);
+        }
+
+        Fl::add_timeout(cfg.main.song_delay, &update_song);
+
     }
     else
     {
@@ -559,9 +707,19 @@ void songfile_timer(void* user_data)
             else if(song[len-1] == '\n') // OSX, Linux
                 song[len-1] = '\0';
             
-            cfg.main.song = (char*) realloc(cfg.main.song, strlen(song) +1);
-            strcpy(cfg.main.song, song);
-            update_song(0);
+            // Remove UTF-8 BOM
+            if ((uint8_t)song[0] == 0xEF && (uint8_t)song[1] == 0xBB && (uint8_t)song[2] == 0xBF)
+            {
+                cfg.main.song = (char*) realloc(cfg.main.song, strlen(song) +1);
+                strcpy(cfg.main.song, song+3);
+            }
+            else
+            {
+                cfg.main.song = (char*) realloc(cfg.main.song, strlen(song) +1);
+                strcpy(cfg.main.song, song);
+            }
+            
+            Fl::add_timeout(cfg.main.song_delay, &update_song);
         }
     }
 
@@ -584,14 +742,14 @@ void app_timer(void* user_data)
     
     if(current_track_app != NULL)
     {
-        const char* track = current_track_app();
+        const char* track = current_track_app(cfg.main.app_artist_title_order);
         if(track != NULL)
         {
             if(cfg.main.song == NULL || strcmp(cfg.main.song, track) || reset == 1)
             {
                 cfg.main.song = (char*) realloc(cfg.main.song, strlen(track) + 1);
                 strcpy(cfg.main.song, track);
-                update_song(0);
+                Fl::add_timeout(cfg.main.song_delay, &update_song);
             }
             free((void*)track);
         }
@@ -601,7 +759,7 @@ void app_timer(void* user_data)
             {
                 cfg.main.song = (char*) realloc(cfg.main.song, 1);
                 strcpy(cfg.main.song, "");
-                update_song(0);
+                Fl::add_timeout(cfg.main.song_delay, &update_song);
             }
         }
     }
