@@ -52,11 +52,16 @@
 #include "parseconfig.h"
 #include "vu_meter.h"
 #include "util.h"
+#include "sockfuncs.h"
 #include "flgui.h"
 #include "fl_funcs.h"
 #include "fl_timer_funcs.h"
 #include "command.h"
 #include "update.h"
+#include "tray_agent.h"
+#ifdef WITH_RADIOCO
+ #include "radioco.h"
+#endif
 #ifdef HAVE_LIBFDK_AAC
  #include "aac_encode.h"
 #endif
@@ -102,21 +107,13 @@ flac_enc flac_rec;
 
 void print_usage(void) 
 {
-    printf("Usage: butt [-h | -s [name] -Sdrt | -c <config_path>] [-A | -x] [-a <addr>] [-p <port>]\n");
+    printf("Usage: butt [-h | -s [name] | -u <song name> | -Sdrtqn | -c <config_path>] [-A | -x] [-a <addr>] [-p <port>]\n");
+    fflush(stdout);
 }
 
 void load_AAC_lib(void)
 {
 #ifdef WIN32
-    fl_g->window_main->icon((char *)LoadIcon(fl_display, MAKEINTRESOURCE(IDI_ICON)));
-    // The fltk icon code above only loads the default icon.
-    // Here, once the window is shown, we can assign
-    // additional icons, just to make things look a bit nicer.
-    HANDLE bigicon = LoadImage(GetModuleHandle(0), MAKEINTRESOURCE(IDI_ICON), IMAGE_ICON, 32, 32, 0);
-    SendMessage(fl_xid(fl_g->window_main), WM_SETICON, ICON_BIG, (LPARAM)bigicon);
-    HANDLE smallicon = LoadImage(GetModuleHandle(0), MAKEINTRESOURCE(IDI_ICON), IMAGE_ICON, 16, 16, 0);
-    SendMessage(fl_xid(fl_g->window_main), WM_SETICON, ICON_SMALL, (LPARAM)smallicon);
-
     // Load aac library
     HMODULE hModule = LoadLibrary(TEXT("libfdk-aac-2.dll"));
     if (hModule != NULL)
@@ -158,10 +155,17 @@ void load_AAC_lib(void)
 int read_cfg(void)
 {
     char *p;
+    int shift_pressed;
 
+    if (Fl::get_key(FL_Shift_L) || Fl::get_key(FL_Shift_R))
+        shift_pressed = 1;
+    else
+        shift_pressed = 0;
+    
+    
     // Prepare configuration loading
 #ifdef WIN32
-    if(cfg_path == NULL)
+    if((cfg_path == NULL) || (shift_pressed == 1))
     {
         if((p = fl_getenv("APPDATA")) == NULL)
         {
@@ -175,10 +179,9 @@ int read_cfg(void)
             cfg_path = (char*)malloc((PATH_MAX+strlen(CONFIG_FILE)+1) * sizeof(char));
             snprintf(cfg_path, PATH_MAX+strlen(CONFIG_FILE), "%s\\%s", p, CONFIG_FILE);
         }
-        
     }
-#else //UNIX
-    if(cfg_path == NULL)
+#else //UNIX/MacOS
+    if((cfg_path == NULL) || (shift_pressed == 1))
     {
         if((p = fl_getenv("HOME")) == NULL)
         {
@@ -193,19 +196,43 @@ int read_cfg(void)
     }
 #endif
     
+    if (shift_pressed)
+    {
+        int rc = fl_choice(_("The shift key was held down during startup.\n"
+                             "Do you want to start butt with a new configuration file?\n"
+                             "This will overwrite your existing configuration file at\n%s"), 0, _("Start with old"), _("Start with new"), cfg_path);
+        if(rc == 2)
+        {
+            if(cfg_create_default())
+            {
+                fl_alert(_("Could not create config %s\nbutt is going to close now"), cfg_path);
+                return 1;
+            }
+        }
+    }
+    
     printf(_("Reading config %s\n"), cfg_path);
+    fflush(stdout);
     
     if(cfg_set_values(NULL) != 0)        //read config file and initialize config struct
     {
         printf(_("Could not find config %s\n"), cfg_path);
+        fflush(stdout);
         if(cfg_create_default())
         {
             fl_alert(_("Could not create config %s\nbutt is going to close now"), cfg_path);
             return 1;
         }
         printf(_("butt created a default config at\n%s\n"), cfg_path);
+        fflush(stdout);
         cfg_set_values(NULL);
     }
+
+    if (cfg.audio.dev_count == 0)
+    {
+        ALERT(_("Could not find any audio device with input channels.\nbutt requires at least one audio device with input channels in order to work.\nThis can either be a built-in audio device, an external audio device or a virtual audio device.\n\nbutt is going to close now."));
+        return 1;
+    }
     
     return 0;
 
@@ -259,6 +286,9 @@ void set_locale_from_config(void)
         case LANG_EN:
             strcpy(lang_str, "en");
             break;
+        case LANG_FR:
+            strcpy(lang_str, "fr");
+            break;
         default:
             return;
     }
@@ -300,10 +330,24 @@ void set_locale_from_config(void)
 
 int main(int argc, char *argv[])
 {
+  
     char lcd_buf[33];
     char info_buf[256];
-    cfg_path = NULL;
+    int opt;
+    int port = 1256;
+    int search_port = 1;
+    int server_mode = SERVER_MODE_LOCAL;
+    char server_addr[128];
     
+  
+    
+    cfg_path = NULL;
+    command_t command;
+    command.cmd = CMD_EMPTY;
+    command.param_size = 0;
+    
+    snprintf(server_addr, sizeof(server_addr), "%s", "127.0.0.1");
+
 #ifndef WIN32
     //ignore the SIGPIPE signal. (In case the server closes the connection unexpected)
     signal(SIGPIPE, SIG_IGN);
@@ -313,19 +357,10 @@ int main(int argc, char *argv[])
     set_locale_from_system();
 #endif
 
-
-
-    int opt;
-    int port = 1256;
-    int server_mode = SERVER_MODE_LOCAL;
-    char server_addr[128];
-    snprintf(server_addr, sizeof(server_addr), "%s", "127.0.0.1");
-    command_t command;
-    command.cmd = CMD_EMPTY;
-    command.param_size = 0;
+    sock_init();
     
     // Parse command line parameters
-    while((opt = getopt(argc, argv, ":hc:Axs:drta:p:S")) != -1)
+    while((opt = getopt(argc, argv, ":hc:Axs:drtnqu:a:p:S")) != -1)
     {
         switch(opt)
         {
@@ -337,7 +372,7 @@ int main(int argc, char *argv[])
                 break;
             case 's':
                 command.cmd = CMD_CONNECT;
-                command.param_size = strlen(optarg)+1;
+                command.param_size = (uint32_t)strlen(optarg)+1;
                 command.param = (char*)malloc(command.param_size);
                 sprintf((char*)command.param, "%s", optarg);
                 break;
@@ -350,6 +385,18 @@ int main(int argc, char *argv[])
             case 't':
                 command.cmd = CMD_STOP_RECORDING;
                 break;
+            case 'n':
+                command.cmd = CMD_SPLIT_RECORDING;
+                break;
+            case 'q':
+                command.cmd = CMD_QUIT;
+                break;
+            case 'u':
+                command.cmd = CMD_UPDATE_SONGNAME;
+                command.param_size = (uint32_t)strlen(optarg)+1;
+                command.param = (char*)malloc(command.param_size);
+                sprintf((char*)command.param, "%s", optarg);
+                break;
             case 'a':
                 memset(server_addr, 0, sizeof(server_addr));
                 snprintf(server_addr, sizeof(server_addr), "%s", optarg);
@@ -358,8 +405,10 @@ int main(int argc, char *argv[])
                 port = atoi(optarg);
                 if (port < 1024 || port > 65535) {
                     printf(_("Illegal argument: Port must be a number between 1023 and 65535\n"));
+                    fflush(stdout);
                     return 1;
                 }
+                search_port = 0;
                 break;
             case 'c':
                 cfg_path = (char*)malloc((strlen(optarg)+1) * sizeof(char));
@@ -380,10 +429,14 @@ int main(int argc, char *argv[])
                        "-d\tDisconnect from streaming server\n"
                        "-r\tStart recording\n"
                        "-t\tStop recording\n"
+                       "-n\tSplit recording\n"
+                       "-q\tQuit butt\n"
+                       "-u\tupdate song name\n"
                        "-S\tRequest status\n"
                        "-a\tAddress of the butt instance to be controlled (default: 127.0.0.1)\n"
                        "-p\tPort of the butt instance to be controlled (default: 1256)\n")
                       );
+                fflush(stdout);
                 return 0;
             case '?':
                 printf(_("Illegal option -%c.\nType butt -h to get a list of supported options.\n"), optopt);
@@ -417,6 +470,8 @@ int main(int argc, char *argv[])
         if (ret < 0)
         {
             printf(_("No butt instance running on %s at port %d\n"), server_addr, port);
+            fflush(stdout);
+
             return 1;
         }
         
@@ -429,6 +484,7 @@ int main(int argc, char *argv[])
                 int connecting = (status & (1<<STATUS_CONNECTING)) > 0;
                 int recording = (status & (1<<STATUS_RECORDING)) > 0;
                 printf(_("connected: %d\nconnecting: %d\nrecording: %d\n"), connected, connecting, recording);
+                fflush(stdout);
             }
             else 
                 return 1;
@@ -443,6 +499,7 @@ int main(int argc, char *argv[])
         return 1;
     }
 
+    load_AAC_lib();
 
     if (read_cfg() != 0)
         return 1;
@@ -462,11 +519,11 @@ int main(int argc, char *argv[])
 #endif
 
     fl_g = new flgui();
+    fl_g->window_main->xclass("butt_FLTK");
 
     fl_g->window_main->show();
     fl_font(fl_font(), 10);
 
-    load_AAC_lib();
     
 #ifdef WIN32 
     fl_g->window_main->icon((char *)LoadIcon(fl_display, MAKEINTRESOURCE(IDI_ICON)));
@@ -477,7 +534,6 @@ int main(int argc, char *argv[])
     SendMessage(fl_xid(fl_g->window_main), WM_SETICON, ICON_BIG, (LPARAM)bigicon); 
     HANDLE smallicon = LoadImage(GetModuleHandle(0), MAKEINTRESOURCE(IDI_ICON), IMAGE_ICON, 16, 16, 0); 
     SendMessage(fl_xid(fl_g->window_main), WM_SETICON, ICON_SMALL, (LPARAM)smallicon); 
-
 #endif 
 
 #if defined(__APPLE__)
@@ -512,15 +568,15 @@ int main(int argc, char *argv[])
     strcpy(lcd_buf, _("idle"));
     print_lcd(lcd_buf, strlen(lcd_buf), 0, 1);
 
-	if(cfg.main.connect_at_startup)
-		button_connect_cb();
+    if(cfg.main.connect_at_startup)
+	button_connect_cb();
     else if (cfg.main.signal_threshold > 0)
         Fl::add_timeout(1, &stream_signal_timer);
 
     if (cfg.main.silence_threshold > 0)
         Fl::add_timeout(1, &stream_silence_timer);
     
-    if(cfg.rec.rec_after_launch)
+    if(cfg.rec.rec_after_launch && !recording)
         button_record_cb();
     else if (cfg.rec.signal_threshold > 0)
          Fl::add_timeout(1, &record_signal_timer);
@@ -528,11 +584,23 @@ int main(int argc, char *argv[])
     if (cfg.rec.silence_threshold > 0)
         Fl::add_timeout(1, &record_silence_timer);
 
-    if (server_mode != SERVER_MODE_OFF && command_start_server(port, server_mode) != 0) 
+    if (server_mode != SERVER_MODE_OFF)
     {
-        snprintf(info_buf, sizeof(info_buf), _("Warning: could not start command server on port %d\n"), port);
-        printf("%s", info_buf);
-        print_info(info_buf, 0);
+        int command_port = command_start_server(port, search_port, server_mode);
+        if (command_port > 0)
+        {
+            snprintf(info_buf, sizeof(info_buf), _("Command server listening on port %d\n"), command_port);
+            printf("%s", info_buf);
+            fflush(stdout);
+            //print_info(info_buf, 0);
+        }
+        else
+        {
+            snprintf(info_buf, sizeof(info_buf), _("Warning: could not start command server on port %d\n"), port);
+            printf("%s", info_buf);
+            fflush(stdout);
+            print_info(info_buf, 0);
+        }
     }
     
     if (cfg.main.check_for_update) 
@@ -545,10 +613,14 @@ int main(int argc, char *argv[])
         if (ret == UPDATE_NEW_VERSION)
         {
             new_version = update_get_version();
-            rc = fl_choice(_("New version available: %s\nYou have version %s"), _("Cancel"), _("Get new version"), NULL, new_version, VERSION);
-            if(rc == 1)
+            rc = fl_choice(_("New version available: %s\nYou have version %s"), _("Don't ask again"), _("Cancel"), _("Get new version"), new_version, VERSION);
+            if(rc == 0)
             {
-                snprintf(uri, sizeof(uri)-1, "https://sourceforge.net/projects/butt/files/butt/butt-%s/", new_version);
+                cfg.main.check_for_update = 0;
+            }
+            if(rc == 2)
+            {
+                snprintf(uri, sizeof(uri)-1, "https://danielnoethen.de/butt/index.html#_download");
                 fl_open_uri(uri);
             }
         }
@@ -556,8 +628,28 @@ int main(int argc, char *argv[])
     
     fill_cfg_widgets();
     
-    GUI_LOOP();
+    
+#ifdef WIN32
+    if (cfg.main.minimize_to_tray == 1)
+        fl_g->window_main->minimize_to_tray = true;
 
-    return 0;
+    if (cfg.main.start_agent == 1) 
+        if ( (tray_agent_start() == 0) && (cfg.gui.start_minimized == 0) )
+	    tray_agent_send_cmd(TA_START);
+
+#else
+    fl_g->group_agent->deactivate();
+#endif
+
+#ifndef WITH_RADIOCO
+    fl_g->radio_add_srv_radioco->hide();
+#endif
+
+
+    if (cfg.gui.start_minimized == 1)
+        fl_g->window_main->iconize();
+    
+        
+    return GUI_LOOP();
 }
 
