@@ -99,7 +99,7 @@ int cfg_write_file(char *path)
 
     fprintf(cfg_fd, "song_update = %d\n", cfg.main.song_update);
     
-    
+    fprintf(cfg_fd, "song_delay = %d\n", cfg.main.song_delay);
     
     
     if (cfg.main.song_prefix != NULL)
@@ -128,12 +128,16 @@ int cfg_write_file(char *path)
     
     fprintf(cfg_fd, "app_update_service = %d\n", cfg.main.app_update_service);
     fprintf(cfg_fd, "app_update = %d\n", cfg.main.app_update);
+    fprintf(cfg_fd, "app_artist_title_order = %d\n", cfg.main.app_artist_title_order);
+
 
     fprintf(cfg_fd, "gain = %f\n", cfg.main.gain);
 
     fprintf(cfg_fd, "silence_threshold = %d\n", cfg.main.silence_threshold);
     fprintf(cfg_fd, "signal_threshold = %d\n", cfg.main.signal_threshold);
     fprintf(cfg_fd, "check_for_update = %d\n", cfg.main.check_for_update);
+    fprintf(cfg_fd, "start_agent = %d\n", cfg.main.start_agent);
+    fprintf(cfg_fd, "minimize_to_tray = %d\n", cfg.main.minimize_to_tray);
     fprintf(cfg_fd, "connect_at_startup = %d\n", cfg.main.connect_at_startup);
     fprintf(cfg_fd, "force_reconnecting = %d\n", cfg.main.force_reconnecting);
 
@@ -152,6 +156,7 @@ int cfg_write_file(char *path)
     fprintf(cfg_fd,
             "[audio]\n"
             "device = %d\n"
+            "dev_remember = %d\n"
             "samplerate = %d\n"
             "bitrate = %d\n"
             "channel = %d\n"
@@ -159,14 +164,13 @@ int cfg_write_file(char *path)
             "right_ch = %d\n"
             "codec = %s\n"
             "mono_to_stereo = %d\n"
-            "aac_overwrite_aot = %d\n"
-            "aac_aot = %d\n"
             "resample_mode = %d\n"
             "silence_level = %f\n"
             "signal_level = %f\n"
             "disable_dithering = %d\n"
-            "buffer_ms = %d\n\n",
+            "buffer_ms = %d\n",
             cfg.audio.dev_num,
+            cfg.audio.dev_remember,
             cfg.audio.samplerate,
             cfg.audio.bitrate,
             cfg.audio.channel,
@@ -174,14 +178,18 @@ int cfg_write_file(char *path)
             cfg.audio.right_ch,
             cfg.audio.codec,
             cfg.audio.mono_to_stereo,
-            cfg.audio.aac_overwrite_aot,
-            cfg.audio.aac_aot,
             cfg.audio.resample_mode,
             cfg.audio.silence_level,
             cfg.audio.signal_level,
             cfg.audio.disable_dithering,
             cfg.audio.buffer_ms
            );
+    
+    if (cfg.audio.dev_name != NULL)
+        fprintf(cfg_fd, "dev_name = %s\n\n", cfg.audio.dev_name);
+    else
+        fprintf(cfg_fd, "dev_name = \n\n");
+
 
     fprintf(cfg_fd, 
             "[record]\n"
@@ -225,7 +233,13 @@ int cfg_write_file(char *path)
             "gain3 = %f\n"
             "gain4 = %f\n"
             "gain5 = %f\n"
+            "gain6 = %f\n"
+            "gain7 = %f\n"
+            "gain8 = %f\n"
+            "gain9 = %f\n"
+            "gain10 = %f\n"
 			"compressor = %d\n"
+            "aggressive_mode = %d\n"
 			"threshold = %f\n"
 			"ratio = %f\n"
 			"attack = %f\n"
@@ -237,7 +251,13 @@ int cfg_write_file(char *path)
             cfg.dsp.gain3,
             cfg.dsp.gain4,
             cfg.dsp.gain5,
+            cfg.dsp.gain6,
+            cfg.dsp.gain7,
+            cfg.dsp.gain8,
+            cfg.dsp.gain9,
+            cfg.dsp.gain10,
 			cfg.dsp.compressor,
+            cfg.dsp.aggressive_mode,
 			cfg.dsp.threshold,
 			cfg.dsp.ratio,
 			cfg.dsp.attack,
@@ -254,7 +274,9 @@ int cfg_write_file(char *path)
             "x_pos = %d\n"
             "y_pos = %d\n"
             "lcd_auto = %d\n"
-            "lang = %d\n\n",
+            "start_minimized = %d\n"
+            "lang = %d\n"
+            "vu_mode = %d\n\n",
             cfg.gui.attach,
             cfg.gui.ontop,
             cfg.gui.hide_log_window,
@@ -262,9 +284,114 @@ int cfg_write_file(char *path)
             cfg.gui.x_pos,
             cfg.gui.y_pos,
             cfg.gui.lcd_auto,
-            cfg.gui.lang
+            cfg.gui.start_minimized,
+            cfg.gui.lang,
+            cfg.gui.vu_mode
            );
 
+    fprintf(cfg_fd, 
+            "[mp3_codec_stream]\n"
+            "enc_quality = %d\n"
+            "stereo_mode = %d\n"
+            "bitrate_mode = %d\n"
+            "vbr_quality = %d\n"
+            "vbr_min_bitrate = %d\n"
+            "vbr_max_bitrate = %d\n\n",
+            cfg.mp3_codec_stream.enc_quality,
+            cfg.mp3_codec_stream.stereo_mode,
+            cfg.mp3_codec_stream.bitrate_mode,
+            cfg.mp3_codec_stream.vbr_quality,
+            cfg.mp3_codec_stream.vbr_min_bitrate,
+            cfg.mp3_codec_stream.vbr_max_bitrate
+            );
+
+    fprintf(cfg_fd, 
+            "[mp3_codec_rec]\n"
+            "enc_quality = %d\n"
+            "stereo_mode = %d\n"
+            "bitrate_mode = %d\n"
+            "vbr_quality = %d\n"
+            "vbr_min_bitrate = %d\n"
+            "vbr_max_bitrate = %d\n\n",
+            cfg.mp3_codec_rec.enc_quality,
+            cfg.mp3_codec_rec.stereo_mode,
+            cfg.mp3_codec_rec.bitrate_mode,
+            cfg.mp3_codec_rec.vbr_quality,
+            cfg.mp3_codec_rec.vbr_min_bitrate,
+            cfg.mp3_codec_rec.vbr_max_bitrate
+            );
+
+
+    fprintf(cfg_fd, 
+            "[vorbis_codec_stream]\n"
+            "bitrate_mode = %d\n"
+            "vbr_quality = %d\n"
+            "vbr_min_bitrate = %d\n"
+            "vbr_max_bitrate = %d\n\n",
+            cfg.vorbis_codec_stream.bitrate_mode,
+            cfg.vorbis_codec_stream.vbr_quality,
+            cfg.vorbis_codec_stream.vbr_min_bitrate,
+            cfg.vorbis_codec_stream.vbr_max_bitrate
+            );
+
+    fprintf(cfg_fd, 
+            "[vorbis_codec_rec]\n"
+            "bitrate_mode = %d\n"
+            "vbr_quality = %d\n"
+            "vbr_min_bitrate = %d\n"
+            "vbr_max_bitrate = %d\n\n",
+            cfg.vorbis_codec_rec.bitrate_mode,
+            cfg.vorbis_codec_rec.vbr_quality,
+            cfg.vorbis_codec_rec.vbr_min_bitrate,
+            cfg.vorbis_codec_rec.vbr_max_bitrate
+            );
+    
+    fprintf(cfg_fd,
+            "[opus_codec_stream]\n"
+            "bitrate_mode = %d\n"
+            "quality = %d\n"
+            "audio_type = %d\n"
+            "bandwidth = %d\n\n",
+            cfg.opus_codec_stream.bitrate_mode,
+            cfg.opus_codec_stream.quality,
+            cfg.opus_codec_stream.audio_type,
+            cfg.opus_codec_stream.bandwidth
+            );
+
+    fprintf(cfg_fd,
+            "[opus_codec_rec]\n"
+            "bitrate_mode = %d\n"
+            "quality = %d\n"
+            "audio_type = %d\n"
+            "bandwidth = %d\n\n",
+            cfg.opus_codec_rec.bitrate_mode,
+            cfg.opus_codec_rec.quality,
+            cfg.opus_codec_rec.audio_type,
+            cfg.opus_codec_rec.bandwidth
+            );
+
+     fprintf(cfg_fd,
+            "[aac_codec_stream]\n"
+            "bitrate_mode = %d\n"
+            "afterburner = %d\n"
+            "profile = %d\n\n",
+            cfg.aac_codec_stream.bitrate_mode,
+            cfg.aac_codec_stream.afterburner,
+            cfg.aac_codec_stream.profile
+            );
+
+     fprintf(cfg_fd,
+            "[aac_codec_rec]\n"
+            "bitrate_mode = %d\n"
+            "afterburner = %d\n"
+            "profile = %d\n\n",
+            cfg.aac_codec_rec.bitrate_mode,
+            cfg.aac_codec_rec.afterburner,
+            cfg.aac_codec_rec.profile
+            );
+
+    
+
     for (i = 0; i < cfg.main.num_of_srv; i++)
     {
         fprintf(cfg_fd, 
@@ -344,6 +471,8 @@ int cfg_write_file(char *path)
 
     }
 
+
+
     fclose(cfg_fd);
 
     snprintf(info_buf, sizeof(info_buf), _("Config written to %s"), path);
@@ -365,30 +494,33 @@ int cfg_set_values(char *path)
     if(cfg_parse_file(path) == -1)
         return 1;
 
-    cfg.main.log_file    = cfg_get_str("main", "log_file");
-    cfg.main.ic_charset  = cfg_get_str("main", "ic_charset");
+    cfg.main.log_file       = cfg_get_str("main", "log_file");
+    cfg.main.ic_charset     = cfg_get_str("main", "ic_charset");
 
-    cfg.audio.dev_num    = cfg_get_int("audio", "device");
-    cfg.audio.samplerate = cfg_get_int("audio", "samplerate");
-    cfg.audio.resolution = 16;
-    cfg.audio.bitrate    = cfg_get_int("audio", "bitrate");
-    cfg.audio.channel    = cfg_get_int("audio", "channel");
-    cfg.audio.left_ch    = cfg_get_int("audio", "left_ch");
-    cfg.audio.right_ch   = cfg_get_int("audio", "right_ch");
-    cfg.audio.codec      = cfg_get_str("audio", "codec");
-    cfg.audio.buffer_ms  = cfg_get_int("audio", "buffer_ms");
-    cfg.audio.aac_aot    = cfg_get_int("audio", "aac_aot");
+    cfg.audio.dev_num       = cfg_get_int("audio", "device");
+    cfg.audio.dev_name      = cfg_get_str("audio", "dev_name");
+    cfg.audio.dev_remember  = cfg_get_int("audio", "dev_remember");
+    cfg.audio.samplerate    = cfg_get_int("audio", "samplerate");
+    cfg.audio.resolution    = 16;
+    cfg.audio.bitrate       = cfg_get_int("audio", "bitrate");
+    cfg.audio.channel       = cfg_get_int("audio", "channel");
+    cfg.audio.left_ch       = cfg_get_int("audio", "left_ch");
+    cfg.audio.right_ch      = cfg_get_int("audio", "right_ch");
+    cfg.audio.codec         = cfg_get_str("audio", "codec");
+    cfg.audio.buffer_ms     = cfg_get_int("audio", "buffer_ms");
     
     cfg.audio.disable_dithering = cfg_get_int("audio", "disable_dithering");
     cfg.audio.pcm_list   = snd_get_devices(&cfg.audio.dev_count);
     
     cfg.audio.mono_to_stereo = cfg_get_int("audio", "mono_to_stereo");
     cfg.audio.resample_mode  = cfg_get_int("audio", "resample_mode");
-    cfg.audio.aac_overwrite_aot = cfg_get_int("audio", "aac_overwrite_aot");
     
     if(cfg.audio.dev_num < 0)
         cfg.audio.dev_num = 0;
-
+    
+    if (cfg.audio.dev_remember < 0)
+        cfg.audio.dev_remember = REMEMBER_BY_ID;
+    
     if(cfg.audio.samplerate == -1)
         cfg.audio.samplerate = 44100;
 
@@ -413,7 +545,7 @@ int cfg_set_values(char *path)
         cfg.audio.codec = (char*)malloc(5*sizeof(char));
         strcpy(cfg.audio.codec, "mp3");
     }
-    else //Make sure that also "opus" and "flac" fits into the codec char array
+    else //Make sure that also "opus" and "flac" fit into the codec char array
         cfg.audio.codec = (char*)realloc((char*)cfg.audio.codec, 5*sizeof(char));
 
     if(!strcmp(cfg.audio.codec, "aac") && g_aac_lib_available == 0) {
@@ -433,20 +565,10 @@ int cfg_set_values(char *path)
     if(cfg.audio.buffer_ms == -1)
         cfg.audio.buffer_ms = 50;
 
-    if(cfg.audio.aac_overwrite_aot == -1)
-        cfg.audio.aac_overwrite_aot = 0;
-    
     if(cfg.audio.disable_dithering == -1)
         cfg.audio.disable_dithering = 0;
     
     
-#ifdef HAVE_LIBFDK_AAC
-    aac_stream.overwrite_aot = cfg.audio.aac_overwrite_aot;
-    aac_rec.overwrite_aot = cfg.audio.aac_overwrite_aot;
-#endif
-
-    if(cfg.audio.aac_aot == -1)
-        cfg.audio.aac_aot = 5;
 
     if(cfg.audio.resample_mode == -1)
         cfg.audio.resample_mode = 0; //SRC_SINC_BEST_QUALITY
@@ -505,12 +627,33 @@ int cfg_set_values(char *path)
         strcpy(cfg.rec.filename, "rec_%Y%m%d-%H%M%S_%i.mp3");
     }
 
+
     if(cfg.rec.folder == NULL)
     {
-        cfg.rec.folder = (char*)malloc(3*sizeof(char));
-        strcpy(cfg.rec.folder, "./");
+        char *p;
+        cfg.rec.folder = (char*)malloc(PATH_MAX*sizeof(char));
+#ifdef WIN32
+        p = fl_getenv("USERPROFILE");
+        if (p != NULL)
+            snprintf(cfg.rec.folder, PATH_MAX, "%s\\Music\\", p);
+        else
+            snprintf(cfg.rec.folder, PATH_MAX, "./");
+#elif __APPLE__
+        p = fl_getenv("HOME");
+        if (p != NULL)
+            snprintf(cfg.rec.folder, PATH_MAX, "%s/Music/", p);
+        else
+            snprintf(cfg.rec.folder, PATH_MAX, "~/");
+#else //UNIX
+        p = fl_getenv("HOME");
+        if (p != NULL)
+            snprintf(cfg.rec.folder, PATH_MAX, "%s/", p);
+        else
+            snprintf(cfg.rec.folder, PATH_MAX, "~/");
+#endif
     }
     
+    
     if(cfg.rec.silence_threshold == -1)
         cfg.rec.silence_threshold = 0;
     
@@ -530,9 +673,10 @@ int cfg_set_values(char *path)
         fl_alert(_("error while parsing config. Illegal value (-1) for num_of_srv.\nbutt is going to close now"));
         exit(1);
     }
+    
     if(cfg.main.num_of_srv > 0)
     {
-        cfg.main.srv     = cfg_get_str("main", "server");
+        cfg.main.srv = cfg_get_str("main", "server");
         if(cfg.main.srv == NULL)
         {
             fl_alert(_("error while parsing config. Missing main/server entry.\nbutt is going to close now"));
@@ -608,7 +752,7 @@ int cfg_set_values(char *path)
 #ifdef HAVE_LIBSSL            
             cfg.srv[i]->tls  = cfg_get_int(srv_ent, "tls");
 #else
-	    cfg.srv[i]->tls = 0;
+            cfg.srv[i]->tls = 0;
 #endif
             if( (cfg.srv[i]->tls != 0) && (cfg.srv[i]->tls != 1) )
                 cfg.srv[i]->tls = 0;
@@ -625,7 +769,10 @@ int cfg_set_values(char *path)
 
             srv_ent = strtok(NULL, ";");
         }
+        free(strtok_buf);
     }// if(cfg.main.num_of_srv > 0)
+    else
+        cfg.main.srv = NULL;
 
     cfg.main.num_of_icy = cfg_get_int("main", "num_of_icy");
     if(cfg.main.num_of_icy == -1)
@@ -637,7 +784,7 @@ int cfg_set_values(char *path)
     cfg.selected_icy = 0;
     if(cfg.main.num_of_icy > 0)
     {
-        cfg.main.icy     = cfg_get_str("main", "icy");
+        cfg.main.icy = cfg_get_str("main", "icy");
         if(cfg.main.icy == NULL)
         {
             fl_alert(_("error while parsing config. Missing main/icy entry.\nbutt is going to close now"));
@@ -682,10 +829,10 @@ int cfg_set_values(char *path)
 
             icy_ent = strtok(NULL, ";");
         }
-    }//if(cfg.main.num_of_icy > 0)
-
-    if (strtok_buf != NULL)
         free(strtok_buf);
+    }//if(cfg.main.num_of_icy > 0)
+    else
+        cfg.main.icy = NULL;
 
     cfg.main.song_path = cfg_get_str("main", "song_path");
     
@@ -702,17 +849,26 @@ int cfg_set_values(char *path)
     if(cfg.main.song_update == -1)
         cfg.main.song_update = 0; //song update from file is default set to off
     
+    cfg.main.song_delay = cfg_get_int("main", "song_delay");
+    if(cfg.main.song_delay == -1)
+        cfg.main.song_delay = 0;
+    
     cfg.main.read_last_line = cfg_get_int("main", "read_last_line");
     if(cfg.main.read_last_line == -1)
         cfg.main.read_last_line = 0; // read first line per default
     
     
     cfg.main.app_update = cfg_get_int("main", "app_update");
-    cfg.main.app_update_service = cfg_get_int("main", "app_update_service");
     if(cfg.main.app_update == -1)
         cfg.main.app_update = 0; //Default value, off
+    
+    cfg.main.app_update_service = cfg_get_int("main", "app_update_service");
     if(cfg.main.app_update_service == -1)
         cfg.main.app_update_service = 0; //Default value, first one
+    
+    cfg.main.app_artist_title_order = cfg_get_int("main", "app_artist_title_order");
+    if(cfg.main.app_artist_title_order == -1)
+        cfg.main.app_artist_title_order = APP_TITLE_FIRST; //Default value, "Title - Artist"
 
     
     cfg.main.silence_threshold = cfg_get_int("main", "silence_threshold");
@@ -734,7 +890,15 @@ int cfg_set_values(char *path)
 
 	cfg.main.check_for_update = cfg_get_int("main", "check_for_update");
 	if(cfg.main.check_for_update == -1)
-		cfg.main.check_for_update = 0;
+		cfg.main.check_for_update = 1;
+    
+    cfg.main.start_agent = cfg_get_int("main", "start_agent");
+    if(cfg.main.start_agent == -1)
+        cfg.main.start_agent = 0;
+    
+    cfg.main.minimize_to_tray = cfg_get_int("main", "minimize_to_tray");
+    if(cfg.main.minimize_to_tray == -1)
+        cfg.main.minimize_to_tray = 0;
 
 	cfg.main.gain = cfg_get_float("main", "gain");
 	if(isnan(cfg.main.gain))
@@ -769,11 +933,46 @@ int cfg_set_values(char *path)
     cfg.dsp.gain5 = cfg_get_float("dsp", "gain5");
     if (isnan(cfg.dsp.gain5))
         cfg.dsp.gain5 = 0.0;
+    
+    cfg.dsp.gain6 = cfg_get_float("dsp", "gain6");
+    if (isnan(cfg.dsp.gain6))
+        cfg.dsp.gain6 = 0.0;
+    
+    cfg.dsp.gain7 = cfg_get_float("dsp", "gain7");
+    if (isnan(cfg.dsp.gain7))
+        cfg.dsp.gain7 = 0.0;
+    
+    cfg.dsp.gain8 = cfg_get_float("dsp", "gain8");
+    if (isnan(cfg.dsp.gain8))
+        cfg.dsp.gain8 = 0.0;
+    
+    cfg.dsp.gain9 = cfg_get_float("dsp", "gain9");
+    if (isnan(cfg.dsp.gain9))
+        cfg.dsp.gain9 = 0.0;
+    
+    cfg.dsp.gain10 = cfg_get_float("dsp", "gain10");
+    if (isnan(cfg.dsp.gain10)) {
+        // Reset all EQ gains if band 10 has no config value. This prevents false values when the user updates from an earlier 5-band EQ to the new 10-band EQ
+        cfg.dsp.gain1 = 0.0;
+        cfg.dsp.gain2 = 0.0;
+        cfg.dsp.gain3 = 0.0;
+        cfg.dsp.gain4 = 0.0;
+        cfg.dsp.gain5 = 0.0;
+        cfg.dsp.gain6 = 0.0;
+        cfg.dsp.gain7 = 0.0;
+        cfg.dsp.gain8 = 0.0;
+        cfg.dsp.gain9 = 0.0;
+        cfg.dsp.gain10 = 0.0;
+    }
 	
 	cfg.dsp.compressor = cfg_get_int("dsp", "compressor");
     if (cfg.dsp.compressor == -1)
         cfg.dsp.compressor = 0;
-	
+
+    cfg.dsp.aggressive_mode = cfg_get_int("dsp", "aggressive_mode");
+    if (cfg.dsp.aggressive_mode == -1)
+        cfg.dsp.aggressive_mode = 0;
+    
 	cfg.dsp.threshold = cfg_get_float("dsp", "threshold");
     if (isnan(cfg.dsp.threshold))
         cfg.dsp.threshold = -20.0f; // -20 dBFS
@@ -823,20 +1022,200 @@ int cfg_set_values(char *path)
     cfg.gui.lcd_auto = cfg_get_int("gui", "lcd_auto");
     if(cfg.gui.lcd_auto == -1)
         cfg.gui.lcd_auto = 0;
-    
+   
+    cfg.gui.start_minimized = cfg_get_int("gui", "start_minimized");
+    if(cfg.gui.start_minimized == -1)
+        cfg.gui.start_minimized = 0;
+        
     cfg.gui.lang = cfg_get_int("gui", "lang");
     if(cfg.gui.lang == -1)
         cfg.gui.lang = LANG_SYSTEM;
+    
+    cfg.gui.vu_mode = cfg_get_int("gui", "vu_mode");
+    if(cfg.gui.vu_mode == -1)
+        cfg.gui.vu_mode = VU_MODE_SOLID;
 
     //read FLTK related stuff
     cfg.main.bg_color = cfg_get_int("main", "bg_color");
     if(cfg.main.bg_color == -1)
-        cfg.main.bg_color = 151540480; //dark blue
+        cfg.main.bg_color = 252645120; //dark gray
 
     cfg.main.txt_color = cfg_get_int("main", "txt_color");
     if(cfg.main.txt_color == -1)
         cfg.main.txt_color = -256; //white
 
+
+    //read mp3 codec related stuff
+    cfg.mp3_codec_stream.enc_quality = cfg_get_int("mp3_codec_stream", "enc_quality");
+    if(cfg.mp3_codec_stream.enc_quality == -1)
+        cfg.mp3_codec_stream.enc_quality = 3;
+
+    cfg.mp3_codec_stream.stereo_mode = cfg_get_int("mp3_codec_stream", "stereo_mode");
+    if(cfg.mp3_codec_stream.stereo_mode == -1)
+        cfg.mp3_codec_stream.stereo_mode = 0;
+
+    cfg.mp3_codec_stream.bitrate_mode = cfg_get_int("mp3_codec_stream", "bitrate_mode");
+    if(cfg.mp3_codec_stream.bitrate_mode == -1)
+        cfg.mp3_codec_stream.bitrate_mode = CHOICE_CBR;
+
+    cfg.mp3_codec_stream.vbr_quality = cfg_get_int("mp3_codec_stream", "vbr_quality");
+    if(cfg.mp3_codec_stream.vbr_quality == -1)
+        cfg.mp3_codec_stream.vbr_quality = 4;
+
+    cfg.mp3_codec_stream.vbr_min_bitrate = cfg_get_int("mp3_codec_stream", "vbr_min_bitrate");
+    if(cfg.mp3_codec_stream.vbr_min_bitrate == -1)
+        cfg.mp3_codec_stream.vbr_min_bitrate = 32;
+
+    cfg.mp3_codec_stream.vbr_max_bitrate = cfg_get_int("mp3_codec_stream", "vbr_max_bitrate");
+    if(cfg.mp3_codec_stream.vbr_max_bitrate == -1)
+        cfg.mp3_codec_stream.vbr_max_bitrate = 320;
+
+    cfg.mp3_codec_rec.enc_quality = cfg_get_int("mp3_codec_rec", "enc_quality");
+    if(cfg.mp3_codec_rec.enc_quality == -1)
+        cfg.mp3_codec_rec.enc_quality = 3;
+
+    cfg.mp3_codec_rec.stereo_mode = cfg_get_int("mp3_codec_rec", "stereo_mode");
+    if(cfg.mp3_codec_rec.stereo_mode == -1)
+        cfg.mp3_codec_rec.stereo_mode = 0;
+
+    cfg.mp3_codec_rec.bitrate_mode = cfg_get_int("mp3_codec_rec", "bitrate_mode");
+    if(cfg.mp3_codec_rec.bitrate_mode == -1)
+        cfg.mp3_codec_rec.bitrate_mode = CHOICE_CBR;
+
+    cfg.mp3_codec_rec.vbr_quality = cfg_get_int("mp3_codec_rec", "vbr_quality");
+    if(cfg.mp3_codec_rec.vbr_quality == -1)
+        cfg.mp3_codec_rec.vbr_quality = 4;
+
+    cfg.mp3_codec_rec.vbr_min_bitrate = cfg_get_int("mp3_codec_rec", "vbr_min_bitrate");
+    if(cfg.mp3_codec_rec.vbr_min_bitrate == -1)
+        cfg.mp3_codec_rec.vbr_min_bitrate = 32;
+
+    cfg.mp3_codec_rec.vbr_max_bitrate = cfg_get_int("mp3_codec_rec", "vbr_max_bitrate");
+    if(cfg.mp3_codec_rec.vbr_max_bitrate == -1)
+        cfg.mp3_codec_rec.vbr_max_bitrate = 320;
+
+    
+    //read ogg/vorbis codec related stuff
+    cfg.vorbis_codec_stream.bitrate_mode = cfg_get_int("vorbis_codec_stream", "bitrate_mode");
+    if(cfg.vorbis_codec_stream.bitrate_mode == -1)
+        cfg.vorbis_codec_stream.bitrate_mode = CHOICE_CBR;
+
+    cfg.vorbis_codec_stream.vbr_quality = cfg_get_int("vorbis_codec_stream", "vbr_quality");
+    if(cfg.vorbis_codec_stream.vbr_quality == -1)
+        cfg.vorbis_codec_stream.vbr_quality = 0;
+
+    cfg.vorbis_codec_stream.vbr_min_bitrate = cfg_get_int("vorbis_codec_stream", "vbr_min_bitrate");
+    if(cfg.vorbis_codec_stream.vbr_min_bitrate == -1)
+        cfg.vorbis_codec_stream.vbr_min_bitrate = 0;
+
+    cfg.vorbis_codec_stream.vbr_max_bitrate = cfg_get_int("vorbis_codec_stream", "vbr_max_bitrate");
+    if(cfg.vorbis_codec_stream.vbr_max_bitrate == -1)
+        cfg.vorbis_codec_stream.vbr_max_bitrate = 0;
+
+    cfg.vorbis_codec_rec.bitrate_mode = cfg_get_int("vorbis_codec_rec", "bitrate_mode");
+    if(cfg.vorbis_codec_rec.bitrate_mode == -1)
+        cfg.vorbis_codec_rec.bitrate_mode = CHOICE_CBR;
+
+    cfg.vorbis_codec_rec.vbr_quality = cfg_get_int("vorbis_codec_rec", "vbr_quality");
+    if(cfg.vorbis_codec_rec.vbr_quality == -1)
+        cfg.vorbis_codec_rec.vbr_quality = 0;
+
+    cfg.vorbis_codec_rec.vbr_min_bitrate = cfg_get_int("vorbis_codec_rec", "vbr_min_bitrate");
+    if(cfg.vorbis_codec_rec.vbr_min_bitrate == -1)
+        cfg.vorbis_codec_rec.vbr_min_bitrate = 0;
+
+    cfg.vorbis_codec_rec.vbr_max_bitrate = cfg_get_int("vorbis_codec_rec", "vbr_max_bitrate");
+    if(cfg.vorbis_codec_rec.vbr_max_bitrate == -1)
+        cfg.vorbis_codec_rec.vbr_max_bitrate = 0;
+    
+    
+    //read opus codec related stuff
+    cfg.opus_codec_stream.bitrate_mode = cfg_get_int("opus_codec_stream", "bitrate_mode");
+    if(cfg.opus_codec_stream.bitrate_mode == -1)
+        cfg.opus_codec_stream.bitrate_mode = CHOICE_VBR;
+
+    cfg.opus_codec_stream.quality = cfg_get_int("opus_codec_stream", "quality");
+    if(cfg.opus_codec_stream.quality == -1)
+        cfg.opus_codec_stream.quality = 0;
+
+    cfg.opus_codec_stream.audio_type = cfg_get_int("opus_codec_stream", "audio_type");
+    if(cfg.opus_codec_stream.audio_type == -1)
+        cfg.opus_codec_stream.audio_type = CHOICE_TYPE_MUSIC;
+
+    cfg.opus_codec_stream.bandwidth = cfg_get_int("opus_codec_stream", "bandwidth");
+    if(cfg.opus_codec_stream.bandwidth == -1)
+        cfg.opus_codec_stream.bandwidth = 0;
+    
+    cfg.opus_codec_rec.bitrate_mode = cfg_get_int("opus_codec_rec", "bitrate_mode");
+    if(cfg.opus_codec_rec.bitrate_mode == -1)
+        cfg.opus_codec_rec.bitrate_mode = CHOICE_VBR;
+
+    cfg.opus_codec_rec.quality = cfg_get_int("opus_codec_rec", "quality");
+    if(cfg.opus_codec_rec.quality == -1)
+        cfg.opus_codec_rec.quality = 0;
+
+    cfg.opus_codec_rec.audio_type = cfg_get_int("opus_codec_rec", "audio_type");
+    if(cfg.opus_codec_rec.audio_type == -1)
+        cfg.opus_codec_rec.audio_type = CHOICE_TYPE_MUSIC;
+
+    cfg.opus_codec_rec.bandwidth = cfg_get_int("opus_codec_rec", "bandwidth");
+    if(cfg.opus_codec_rec.bandwidth == -1)
+        cfg.opus_codec_rec.bandwidth = 0;
+
+    //read aac codec related stuff
+    cfg.aac_codec_stream.bitrate_mode = cfg_get_int("aac_codec_stream", "bitrate_mode");
+    if(cfg.aac_codec_stream.bitrate_mode == -1)
+        cfg.aac_codec_stream.bitrate_mode = CHOICE_CBR;
+
+    cfg.aac_codec_stream.profile = cfg_get_int("aac_codec_stream", "profile");
+    if(cfg.aac_codec_stream.profile == -1)
+        cfg.aac_codec_stream.profile = CHOICE_AAC_PROFILE_AUTO;
+
+    cfg.aac_codec_stream.afterburner = cfg_get_int("aac_codec_stream", "afterburner");
+    if(cfg.aac_codec_stream.afterburner == -1)
+        cfg.aac_codec_stream.afterburner = 0; // Afterburner on by default
+
+    cfg.aac_codec_rec.bitrate_mode = cfg_get_int("aac_codec_rec", "bitrate_mode");
+    if(cfg.aac_codec_rec.bitrate_mode == -1)
+        cfg.aac_codec_rec.bitrate_mode = CHOICE_CBR;
+
+    cfg.aac_codec_rec.profile = cfg_get_int("aac_codec_rec", "profile");
+    if(cfg.aac_codec_rec.profile == -1)
+        cfg.aac_codec_rec.profile = CHOICE_AAC_PROFILE_AUTO;
+
+    cfg.aac_codec_rec.afterburner = cfg_get_int("aac_codec_rec", "afterburner");
+    if(cfg.aac_codec_rec.afterburner == -1)
+        cfg.aac_codec_rec.afterburner = 0; // Afterburner on by default
+
+#ifdef HAVE_LIBFDK_AAC
+    // Backward compatability
+    if (cfg_get_int("audio", "aac_overwrite_aot") != -1)
+    {
+        switch (cfg_get_int("audio", "aac_aot"))
+        {
+            case 2:
+                cfg.aac_codec_stream.profile = CHOICE_AAC_PROFILE_AAC_LC;
+                cfg.aac_codec_rec.profile = CHOICE_AAC_PROFILE_AAC_LC;
+                break;
+            case 5:
+                cfg.aac_codec_stream.profile = CHOICE_AAC_PROFILE_HE_AACv1;
+                cfg.aac_codec_rec.profile = CHOICE_AAC_PROFILE_HE_AACv1;
+                break;
+            case 29:
+                cfg.aac_codec_stream.profile = CHOICE_AAC_PROFILE_HE_AACv2;
+                cfg.aac_codec_rec.profile = CHOICE_AAC_PROFILE_HE_AACv2;
+                break;
+            default:
+                cfg.aac_codec_stream.profile = CHOICE_AAC_PROFILE_AUTO;
+                cfg.aac_codec_rec.profile = CHOICE_AAC_PROFILE_AUTO;
+                break;
+        }
+    }
+
+#endif
+
+
+
     return 0;
 }
 
@@ -861,13 +1240,13 @@ int cfg_create_default(void)
     if (p != NULL)
         snprintf(def_rec_folder, PATH_MAX, "%s/Music/", p);
     else
-        snprintf(def_rec_folder, PATH_MAX, "./");
+        snprintf(def_rec_folder, PATH_MAX, "~/");
 #else //UNIX
     p = fl_getenv("HOME");
     if (p != NULL)
         snprintf(def_rec_folder, PATH_MAX, "%s/", p);
     else
-        snprintf(def_rec_folder, PATH_MAX, "./");
+        snprintf(def_rec_folder, PATH_MAX, "~/");
 #endif
 
 
@@ -882,8 +1261,12 @@ int cfg_create_default(void)
             "icy_ent =\n"
             "song_path =\n"
             "song_update = 0\n"
+            "song_delay = 0\n"
             "song_prefix = \n"
             "song_suffix = \n"
+            "app_update = 0\n"
+            "app_update_service = 0\n"
+            "app_artist_title_order = 1\n"
             "read_last_line = 0\n"
             "log_file =\n"
             "gain = 1.0\n"
@@ -891,6 +1274,8 @@ int cfg_create_default(void)
             "silence_threshhold = 0\n"
             "signal_threshhold = 0\n"
             "check_for_update = 0\n"
+            "start_agent = 0\n"
+            "minimize_to_tray = 0\n"
             "force_reconnecting = 0\n"
             "connect_at_startup = 0\n\n"
            );
@@ -904,8 +1289,6 @@ int cfg_create_default(void)
             "codec = mp3\n"
             "mono_to_stereo = 0\n"
             "resample_mode = 0\n" //SRC_SINC_BEST_QUALITY
-            "aac_aot = 5\n" // aac+ v1
-            "aac_overwrite_aot = 0\n"
             "silence_level = 50.0\n"
             "signal_level = 50.0\n"
             "disable_dithering = 0\n"
@@ -944,6 +1327,7 @@ int cfg_create_default(void)
             "gain4 = 0.0\n"
             "gain5 = 0.0\n"
 		    "compressor = 0\n"
+            "aggressive_mode = 0\n"
 			"threshold = -20.0\n"
 			"ratio = 5\n"
 			"attack = 0.01\n"
@@ -960,9 +1344,76 @@ int cfg_create_default(void)
             "x_pos = 0\n"
             "y_pos = 0\n"
             "lcd_auto = 0\n"
+            "start_minimized = 0\n"
             "lang = 0\n\n"
             );
 
+    fprintf(cfg_fd, 
+            "[mp3_codec_stream]\n"
+            "enc_quality = 3\n"
+            "stereo_mode = 0\n"
+            "bitrate_mode = 0\n"
+            "vbr_quality = 4\n"
+            "vbr_min_bitrate = 32\n"
+            "vbr_max_bitrate = 320\n\n"
+            );
+
+    fprintf(cfg_fd, 
+            "[mp3_codec_rec]\n"
+            "enc_quality = 3\n"
+            "stereo_mode = 0\n"
+            "bitrate_mode = 0\n"
+            "vbr_quality = 4\n"
+            "vbr_min_bitrate = 32\n"
+            "vbr_max_bitrate = 320\n\n"
+            );
+    
+    fprintf(cfg_fd,
+            "[vorbis_codec_stream]\n"
+            "bitrate_mode = 0\n"
+            "vbr_quality = 0\n"
+            "vbr_min_bitrate = 0\n"
+            "vbr_max_bitrate = 0\n\n"
+            );
+
+    fprintf(cfg_fd,
+            "[vorbis_codec_rec]\n"
+            "bitrate_mode = 0\n"
+            "vbr_quality = 0\n"
+            "vbr_min_bitrate = 0\n"
+            "vbr_max_bitrate = 0\n\n"
+            );
+    
+    fprintf(cfg_fd,
+            "[opus_codec_stream]\n"
+            "bitrate_mode = 1\n"
+            "quality = 0\n"
+            "audio_type = 0\n"
+            "bandwidth = 0\n\n"
+            );
+    
+    fprintf(cfg_fd,
+            "[opus_codec_rec]\n"
+            "bitrate_mode = 1\n"
+            "quality = 0\n"
+            "audio_type = 0\n"
+            "bandwidth = 0\n\n"
+            );
+
+    fprintf(cfg_fd,
+            "[aac_codec_stream]\n"
+            "bitrate_mode = 0\n"
+            "afterburner = 0\n"
+            "profile = 0\n\n"
+            );
+
+    fprintf(cfg_fd,
+            "[aac_codec_rec]\n"
+            "bitrate_mode = 0\n"
+            "afterburner = 0\n"
+            "profile = 0\n\n"
+            );
+
     fclose(cfg_fd);
 
     return 0;
