@@ -22,7 +22,8 @@
 enum {
 
     SHOUTCAST = 0,
-    ICECAST = 1
+    ICECAST = 1,
+    RADIOCO = 2
 };
 
 enum {
@@ -39,10 +40,44 @@ enum {
     CHOICE_WAV = 5
 };
 
+enum {
+    CHOICE_CBR = 0,
+    CHOICE_VBR = 1,
+    CHOICE_ABR = 2
+};
+
+enum {
+    CHOICE_TYPE_MUSIC = 0,
+    CHOICE_TYPE_SPEECH = 1
+};
+
+enum {
+    CHOICE_AAC_PROFILE_AUTO = 0,
+    CHOICE_AAC_PROFILE_AAC_LC = 1,
+    CHOICE_AAC_PROFILE_HE_AACv1 = 2,
+    CHOICE_AAC_PROFILE_HE_AACv2 = 3
+};
+
 enum {
     LANG_SYSTEM = 0,
     LANG_DE = 1,
-    LANG_EN = 2
+    LANG_EN = 2,
+    LANG_FR = 3
+};
+
+enum {
+    APP_ARTIST_FIRST = 0,
+    APP_TITLE_FIRST = 1
+};
+
+enum {
+    VU_MODE_GRADIENT = 0,
+    VU_MODE_SOLID = 1
+};
+
+enum {
+    REMEMBER_BY_ID = 0,
+    REMEMBER_BY_NAME = 1
 };
 
 extern const char CONFIG_FILE[];
@@ -89,10 +124,12 @@ typedef struct
         FILE *song_fd;
         char *song_prefix;
         char *song_suffix;
+        int song_delay;
         int song_update;   //1 = song info will be read from file
         int read_last_line;
         int app_update;
         int app_update_service;
+        int app_artist_title_order;
         int num_of_srv;
         int num_of_icy;
         int bg_color, txt_color;
@@ -101,6 +138,8 @@ typedef struct
         int silence_threshold; // timeout duration of automatic stream/record stop
         int signal_threshold;  // timeout duration of automatic stream/record start
         int check_for_update;
+        int start_agent;
+        int minimize_to_tray;
         float gain;
         char *log_file;
         char *ic_charset;
@@ -110,6 +149,8 @@ typedef struct
     {
         int dev_count;
         int dev_num;
+        char *dev_name;
+        int dev_remember;       // Remember device by ID or Name
         snd_dev_t **pcm_list;
         int samplerate;
         int resolution;
@@ -120,10 +161,8 @@ typedef struct
         int mono_to_stereo;
         int buffer_ms;
         int resample_mode;
-        int aac_aot;
         float silence_level;
         float signal_level;
-        int aac_overwrite_aot;
         int disable_dithering;
         char *codec;
     }audio;
@@ -158,8 +197,9 @@ typedef struct
     struct
     {
         int equalizer;
-        double gain1, gain2, gain3, gain4, gain5;
+        double gain1, gain2, gain3, gain4, gain5, gain6, gain7, gain8, gain9, gain10;
 		int compressor;
+        int aggressive_mode;
 		double threshold, ratio, attack, release, makeup_gain;
     }dsp;
 
@@ -172,8 +212,76 @@ typedef struct
         int remember_pos;
         int x_pos, y_pos;
         int lang;
+        int vu_mode;
+        int start_minimized;
     }gui;
 
+    struct
+    {
+        int enc_quality;
+        int stereo_mode;
+        int bitrate_mode;
+        int vbr_quality;
+        int vbr_min_bitrate;
+        int vbr_max_bitrate;
+    }mp3_codec_stream;
+
+    struct
+    {
+        int enc_quality;
+        int stereo_mode;
+        int bitrate_mode;
+        int vbr_quality;
+        int vbr_min_bitrate;
+        int vbr_max_bitrate;
+    }mp3_codec_rec;
+
+    struct
+    {
+        int bitrate_mode;
+        int vbr_quality;
+        int vbr_min_bitrate;
+        int vbr_max_bitrate;
+    }vorbis_codec_stream;
+
+    struct
+    {
+        int bitrate_mode;
+        int vbr_quality;
+        int vbr_min_bitrate;
+        int vbr_max_bitrate;
+    }vorbis_codec_rec;
+    
+    struct
+    {
+        int bitrate_mode;
+        int quality;
+        int audio_type;
+        int bandwidth;
+    }opus_codec_stream;
+    
+    struct
+    {
+        int bitrate_mode;
+        int quality;
+        int audio_type;
+        int bandwidth;
+    }opus_codec_rec;
+
+    struct
+    {
+        int bitrate_mode;
+        int profile;
+        int afterburner;
+    }aac_codec_stream;
+    
+    struct
+    {
+        int bitrate_mode;
+        int profile;
+        int afterburner;
+    }aac_codec_rec;
+
     server_t **srv;
     icy_t **icy;
 
