@@ -10,6 +10,6 @@
 #define __butt__currentTrack__
 
 #include <stdio.h>
-typedef const char* (*currentTrackFunction)(void);
+typedef const char* (*currentTrackFunction)(int artist_title_order);
 
 #endif /* defined(__butt__currentTrack__) */
