@@ -142,7 +142,7 @@ static void metadata(void* data, DBusMessageIter* args) {
     } while(dbus_message_iter_next(&arr));
 }
 
-static char* get_mpris(const char* target) {
+static char* get_mpris(const char* target, int artist_title_order) {
     char* playbackStatusValue = NULL;
     char* returnString = NULL;
     struct DBusMethodCall opt = {
@@ -158,60 +158,71 @@ static char* get_mpris(const char* target) {
     if(dbus_bus_name_has_owner(conn, target, &err)) {
         dbus_call_method(&opt, 2, "org.mpris.MediaPlayer2.Player", "PlaybackStatus");
         if(playbackStatusValue != NULL && strcmp(playbackStatusValue, "Stopped")) {
-	    int len;           
+            int len;           
             char* values[2] = { NULL, NULL };
             opt.arg_iter = metadata;
             opt.data = values;
             dbus_call_method(&opt, 2, "org.mpris.MediaPlayer2.Player", "Metadata");
 
-	    if (values[0] != NULL && values[1] != NULL)
-	    {
-		len = strlen(values[1]) + 3 + strlen(values[0]) + 1;                                                   
-		returnString = (char*) malloc(len);
-		snprintf(returnString, len, "%s - %s",values[1], values[0]);
-		free(values[0]);
-		free(values[1]);
-	    }
-	    else if (values[0] != NULL)
-	    {
-		len = strlen(values[0]) + 1;                                                   
-		returnString = (char*) malloc(len);
-		snprintf(returnString, len, "%s",values[0]);
-		free(values[0]);
-	    }
-	    else if (values[1] != NULL)
-	    {
-		len = strlen(values[1]) + 1;                                                   
-		returnString = (char*) malloc(len);
-		snprintf(returnString, len, "%s",values[1]);
-		free(values[1]);
-	    }
+            if (values[0] != NULL && values[1] != NULL)
+            {
+                len = strlen(values[1]) + 3 + strlen(values[0]) + 1;                                                   
+                returnString = (char*) malloc(len);
+                if (artist_title_order == 1) 
+                {
+                    snprintf(returnString, len, "%s - %s",values[0], values[1]);
+                }
+                else 
+                {
+                    snprintf(returnString, len, "%s - %s",values[1], values[0]);
+                }
+                free(values[0]);
+                free(values[1]);
+            }
+            else if (values[0] != NULL)
+            {
+                len = strlen(values[0]) + 1;                                                   
+                returnString = (char*) malloc(len);
+                snprintf(returnString, len, "%s",values[0]);
+                free(values[0]);
+            }
+            else if (values[1] != NULL)
+            {
+                len = strlen(values[1]) + 1;                                                   
+                returnString = (char*) malloc(len);
+                snprintf(returnString, len, "%s",values[1]);
+                free(values[1]);
+            }
 
         }
-	if(playbackStatusValue != NULL)
-	    free(playbackStatusValue);
+        if(playbackStatusValue != NULL)
+            free(playbackStatusValue);
     }
     return returnString;
 }
 
-const char* getCurrentTrackRhythmbox() {
-    return get_mpris("org.gnome.Rhythmbox3");
+const char* getCurrentTrackRhythmbox(int artist_title_order) {
+    return get_mpris("org.gnome.Rhythmbox3", artist_title_order);
 }
 
-const char* getCurrentTrackClementine() {
-    return get_mpris("org.mpris.MediaPlayer2.clementine");
+const char* getCurrentTrackClementine(int artist_title_order) {
+    return get_mpris("org.mpris.MediaPlayer2.clementine", artist_title_order);
 }
 
-const char* getCurrentTrackSpotify() {
-    return get_mpris("org.mpris.MediaPlayer2.spotify");
+const char* getCurrentTrackSpotify(int artist_title_order) {
+    return get_mpris("org.mpris.MediaPlayer2.spotify", artist_title_order);
 }
 
-const char* getCurrentTrackCantata() {
-    return get_mpris("org.mpris.MediaPlayer2.cantata");
+const char* getCurrentTrackCantata(int artist_title_order) {
+    return get_mpris("org.mpris.MediaPlayer2.cantata", artist_title_order);
 }
 
-const char* getCurrentTrackBanshee() {
-    return get_mpris("org.mpris.MediaPlayer2.banshee");
+const char* getCurrentTrackBanshee(int artist_title_order) {
+    return get_mpris("org.mpris.MediaPlayer2.banshee", artist_title_order);
+}
+
+const char* getCurrentTrackStrawberry(int artist_title_order) {
+    return get_mpris("org.mpris.MediaPlayer2.strawberry", artist_title_order);
 }
 
 currentTrackFunction getCurrentTrackFunctionFromId(int i) {
@@ -221,6 +232,7 @@ currentTrackFunction getCurrentTrackFunctionFromId(int i) {
         case 2: return &getCurrentTrackClementine;
         case 3: return &getCurrentTrackSpotify;
         case 4: return &getCurrentTrackCantata;
+        case 5: return &getCurrentTrackStrawberry;
         default: return NULL;
     }
 }
