@@ -87,7 +87,7 @@ int flac_enc_init(flac_enc *flac)
    
     if((flac->encoder = FLAC__stream_encoder_new()) == NULL) 
     {
-        printf("ERROR: allocating encoder\n");
+        fprintf(stderr, "ERROR: allocating encoder\n");
         return 1;
     }
     memset(&flac->vorbis_comment, 0, sizeof(FLAC__StreamMetadata));
@@ -116,6 +116,7 @@ int flac_enc_init_FILE(flac_enc *flac, FILE *fout)
     if(init_status != FLAC__STREAM_ENCODER_INIT_STATUS_OK) 
     {
         fprintf(stderr, "ERROR: initializing encoder: %s\n", FLAC__StreamEncoderInitStatusString[init_status]);
+        
         return 1;
     }
 
@@ -260,6 +261,15 @@ int flac_enc_reinit(flac_enc *flac)
     return flac_enc_init(flac);
 }
 
+void flac_enc_close_file(flac_enc *flac)
+{
+    if(flac->encoder != NULL)
+    {
+        FLAC__stream_encoder_finish(flac->encoder);
+        flac_enc_close(flac);
+    }
+}
+
 void flac_enc_close(flac_enc *flac)
 {
     if(flac->encoder != NULL)
