@@ -235,15 +235,29 @@ int ic_connect(void)
 
 
         // Send audio settings
-        snprintf(send_buf+strlen(send_buf), sizeof(send_buf)-strlen(send_buf),
-                 "ice-audio-info: "
-                 "ice-bitrate=%d;"
-                 "ice-channels=%d;"
-                 "ice-samplerate=%d"
-                 "\r\n",
-                 cfg.audio.bitrate,
-                 cfg.audio.channel,
-                 strcmp(cfg.audio.codec, "opus") == 0 ? 48000 : cfg.audio.samplerate);
+        if(!strcmp(cfg.audio.codec, "flac"))
+        { // Do not send bitrate information if flac is used
+            snprintf(send_buf+strlen(send_buf), sizeof(send_buf)-strlen(send_buf),
+                     "ice-audio-info: "
+                     "ice-channels=%d;"
+                     "ice-samplerate=%d"
+                     "\r\n",
+                     cfg.audio.channel,
+                     strcmp(cfg.audio.codec, "opus") == 0 ? 48000 : cfg.audio.samplerate);
+        }
+        else
+        {
+            snprintf(send_buf+strlen(send_buf), sizeof(send_buf)-strlen(send_buf),
+                     "ice-audio-info: "
+                     "ice-bitrate=%d;"
+                     "ice-channels=%d;"
+                     "ice-samplerate=%d"
+                     "\r\n",
+                     cfg.audio.bitrate,
+                     cfg.audio.channel,
+                     strcmp(cfg.audio.codec, "opus") == 0 ? 48000 : cfg.audio.samplerate);
+        }
+        
 
         //ic_send(send_buf, (int)strlen(send_buf));
 
@@ -259,6 +273,12 @@ int ic_connect(void)
         ic_send(send_buf, (int)strlen(send_buf));
 
         ret = ic_recv(recv_buf, sizeof(recv_buf));
+        
+        //MARK: DEBUG
+        //sprintf(recv_buf, "FOOHTTP/1.1 100 Continue\nContent-Length: 0\r\n\r\n");
+        //print_info(recv_buf, 1);
+        
+
         if (ret == 0)
         {
             if (try_cnt == 0)
@@ -287,7 +307,6 @@ int ic_connect(void)
             return IC_RETRY;
         }
 
-
         char* temp = strdup(recv_buf);
         //We need to extract the HTTP return value from the HTTP response
         //to see if the login was successfull (HTTP/1.0 200 OK)
@@ -306,12 +325,15 @@ int ic_connect(void)
         retval = atoi(http_retval);
         free(temp);
         
-        
-        // Workaround for liquidsoap and icecast-kh in case the user has entered a wrong password
+        // Workaround for liquidsoap and icecast-kh
         if (retval == 100) {
-            if (strstr(recv_buf, " 401 ") != NULL) {
+            if (strstr(recv_buf, " 401 ") != NULL) { // Wrong password
                 retval = 401;
             }
+            
+            if (strstr(recv_buf, " 403 ") != NULL) { // Mounpoint in use (Needed since kh14)
+                retval = 403;
+            }
         }
  
 
@@ -409,8 +431,9 @@ int ic_send(char *buf, int buf_len)
     else
     {
         ret = sock_send(stream_socket, buf, buf_len, SEND_TIMEOUT);
-        if (ret == SOCK_TIMEOUT)
-               ret = -1;
+        if (ret == SOCK_TIMEOUT) {
+            ret = -1;
+        }
     }
    
     return ret;
@@ -492,9 +515,7 @@ int ic_update_song(char *song_name)
 #endif
 
     song_buf = strdup(song_name);
-
-    strrpl(&song_buf, (char*)" ", (char*)"%20", MODE_ALL);
-    strrpl(&song_buf, (char*)"&", (char*)"%26", MODE_ALL);
+    strencoderfc3986(&song_buf);
 
     mount = (char*)malloc(strlen(cfg.srv[cfg.selected_srv]->mount)+2);
 
@@ -505,11 +526,6 @@ int ic_update_song(char *song_name)
 
     snprintf(auth, sizeof(auth), "%s:%s", cfg.srv[cfg.selected_srv]->usr, cfg.srv[cfg.selected_srv]->pwd);
 
-    // Remove UTF-8 BOM
-    if ((uint8_t)song_buf[0] == 0xEF && (uint8_t)song_buf[1] == 0xBB && (uint8_t)song_buf[2] == 0xBF) {
-        song_buf += 3;
-    }
-
     if (cfg.main.ic_charset != NULL) {
         snprintf(send_buf, sizeof(send_buf), "GET /admin/metadata?mode=updinfo&mount=%s&charset=%s&song=%s "
                 "HTTP/1.0\r\n"
