@@ -33,6 +33,29 @@ int lame_enc_init(lame_enc *lame)
     lame_set_in_samplerate(lame->gfp, lame->samplerate);
     lame_set_out_samplerate(lame->gfp, lame->samplerate);
     lame_set_brate(lame->gfp, lame->bitrate);
+    lame_set_quality(lame->gfp, lame->enc_quality);
+    lame_set_VBR_q(lame->gfp, lame->vbr_quality);
+    lame_set_VBR_min_bitrate_kbps(lame->gfp, lame->vbr_min_bitrate);
+    lame_set_VBR_mean_bitrate_kbps(lame->gfp, lame->bitrate);
+    lame_set_VBR_max_bitrate_kbps(lame->gfp, lame->vbr_max_bitrate);
+
+    if (lame->stereo_mode > -1)
+        lame_set_mode(lame->gfp, (MPEG_mode)lame->stereo_mode);
+
+    if (lame->bitrate_mode == 0) // CBR
+        lame_set_VBR(lame->gfp, vbr_off);
+
+    if (lame->bitrate_mode == 1) // VBR
+    {
+        lame_set_VBR(lame->gfp, vbr_default);
+    }
+
+    if (lame->bitrate_mode == 2) // ABR
+    {
+        lame_set_VBR(lame->gfp, vbr_abr);
+    }
+
+
     
     if((rc = lame_init_params(lame->gfp)) < 0)
     {
@@ -42,6 +65,17 @@ int lame_enc_init(lame_enc *lame)
         print_info(info_buf, 1);
         return 1;
     }
+    /*
+    printf("MP3 Quality: %d\n", lame_get_quality(lame->gfp));
+    printf("MP3 Stereo Mode: %d\n", lame_get_mode(lame->gfp));
+    printf("MP3 Bitrate Mode: %d\n", lame_get_VBR(lame->gfp));
+    printf("MP3 vbr: %d\n", lame_get_VBR(lame->gfp));
+    printf("MP3 vbr quality: %d\n", lame_get_VBR_q(lame->gfp));
+    printf("MP3 vbr mean bitrate: %d\n", lame_get_VBR_mean_bitrate_kbps(lame->gfp));
+    printf("MP3 vbr min bitrate: %d\n", lame_get_VBR_min_bitrate_kbps(lame->gfp));
+    printf("MP3 vbr max bitrate: %d\n", lame_get_VBR_max_bitrate_kbps(lame->gfp));
+    printf("\n");
+    */
 
     lame->state = LAME_READY;
     return 0;
