@@ -44,9 +44,11 @@
 #include "vu_meter.h"
 #include "flgui.h"
 #include "fl_funcs.h"
+#include "Fl_LED.h"
 #include "dsp.hpp"
+#include "util.h"
 
-int pa_frames;
+int pa_frames = 0;
 
 char* encode_buf;
 short *pa_pcm_buf;
@@ -59,6 +61,7 @@ bool pa_new_frames;
 bool reconnect;
 bool silence_detected;
 bool signal_detected;
+bool reset_compressor = false;
 
 int num_of_input_channels;
 
@@ -82,6 +85,11 @@ PaStream *stream;
 
 static DSPEffects* dsp = NULL;
 
+void snd_reset_compressor(void)
+{
+    reset_compressor = true;
+}
+
 int snd_init(void)
 {
     char info_buf[256];
@@ -96,6 +104,10 @@ int snd_init(void)
         ALERT(info_buf);
         return 1;
     }
+    
+    if (pa_frames == 0) {
+        pa_frames = 2400; // 50ms * 48000Hz
+    }
 
     srconv_stream.data_in = (float*)malloc(2*pa_frames * 64 * sizeof(float));
     srconv_record.data_in = (float*)malloc(2*pa_frames * 64 * sizeof(float));
@@ -140,9 +152,15 @@ int snd_open_stream(void)
     snd_reset_samplerate_conv(SND_REC);
 
     samplerate = cfg.audio.samplerate;
+    
+    if (cfg.audio.dev_remember == REMEMBER_BY_NAME)
+        cfg.audio.dev_num = snd_get_dev_num_by_name(cfg.audio.dev_name);
+        
+    if (cfg.audio.dev_num == -1)
+        cfg.audio.dev_num = 0;
 
     pa_dev_id = cfg.audio.pcm_list[cfg.audio.dev_num]->dev_id;
-
+    
     pa_dev_info = Pa_GetDeviceInfo(pa_dev_id);
     if(pa_dev_info == NULL)
     {
@@ -217,6 +235,7 @@ int snd_open_stream(void)
     if(pa_err != paNoError)
     {
         printf(_("error opening sound device: \n%s\n"), Pa_GetErrorText(pa_err));
+        fflush(stdout);
         return 1;
     }
 
@@ -227,7 +246,7 @@ int snd_open_stream(void)
     }
     
     dsp = new DSPEffects(pa_frames, cfg.audio.channel, samplerate);
-
+    //dsp->led_threshold = fl_g->LED_comp_threshold;
     
     Pa_StartStream(stream);
     return 0;
@@ -284,8 +303,14 @@ int snd_callback(const void *input,
     }
     samplerate_out = cfg.audio.samplerate;
 
-    if(dsp->hasToProcessSamples())
+    if (dsp->hasToProcessSamples())
     {
+        if (reset_compressor == true)
+        {
+            dsp->reset_compressor();
+            reset_compressor = false;
+        }
+        
         dsp->processSamples(pa_pcm_buf);
     }
     
@@ -385,10 +410,12 @@ void *snd_stream_thread(void *data)
     static int new_stream = 0;
 
 
-    if(cfg.srv[cfg.selected_srv]->type == SHOUTCAST)
-        xc_send = &sc_send;
-    else //Icecast
+    if(cfg.srv[cfg.selected_srv]->type == ICECAST)
         xc_send = &ic_send;
+    else //Icecast
+        xc_send = &sc_send;
+    
+    set_max_thread_priority();
         
     while(connected)
     {
@@ -545,6 +572,9 @@ void* snd_rec_thread(void *data)
     
     ogg_header_written = 0;
     opus_header_written = 0;
+    
+    set_max_thread_priority();
+
 
     while(record)
     {
@@ -615,7 +645,6 @@ void* snd_rec_thread(void *data)
 #endif
         else
         {
-
             if(rb_filled(&rec_rb) < framepacket_size*sizeof(short))
                 continue;
 
@@ -623,10 +652,8 @@ void* snd_rec_thread(void *data)
             if(rb_bytes_read == 0)
                 continue;
 
-
             if(!strcmp(cfg.rec.codec, "mp3"))
             {
-
                 enc_bytes_read = lame_enc_encode(&lame_rec, (short*)audio_buf, enc_buf,
                         rb_bytes_read/(2*cfg.audio.channel), rec_rb.size*10);
                 kbytes_written += fwrite(enc_buf, 1, enc_bytes_read, cfg.rec.fd)/1024.0;
@@ -663,7 +690,7 @@ void* snd_rec_thread(void *data)
     }
 
     if(!strcmp(cfg.rec.codec, "flac"))  // The flac encoder closes the file
-        flac_enc_close(&flac_rec);
+        flac_enc_close_file(&flac_rec);
     else
         fclose(cfg.rec.fd);
     
@@ -711,10 +738,19 @@ void snd_update_vu(void)
     ravg = (decay * rpeak) + (1.0-decay) * ravg;
 
     // Update the vu meter UI only every second call of this function.
-    // This reduces the CPU usage by not missing any samples
+    // This reduces the CPU usage without not missing any samples
     if (call_cnt == 1)
     {
         vu_meter((short)round(lavg), (short)round(ravg));
+        
+        if (cfg.dsp.compressor == 1)
+        {
+            if (dsp->is_compressing == true)
+                fl_g->LED_comp_threshold->set_state(LED::LED_ON);
+            else
+                fl_g->LED_comp_threshold->set_state(LED::LED_OFF);
+        }
+        
         call_cnt = 0;
     }
     else
@@ -723,28 +759,43 @@ void snd_update_vu(void)
         lpeak = 0;
         rpeak = 0;
     }
+    
+    
+  
 
     pa_new_frames = 0;
 }
 
+void snd_free_device_list(void)
+{
+    if (cfg.audio.dev_count == 0)
+        return;
+        
+    for (int i = 0; i < SND_MAX_DEVICES; i++)
+    {
+        if (i < cfg.audio.dev_count)
+            free(cfg.audio.pcm_list[i]->name);
+        
+        free(cfg.audio.pcm_list[i]);
+    }
+    free(cfg.audio.pcm_list);
+}
+
 snd_dev_t **snd_get_devices(int *dev_count)
 {
 	int i, j;
-    int devcount, sr_count, dev_num;
+    int available_devices, sr_count, dev_num;
     bool sr_supported = 0;
     const PaDeviceInfo *p_di;
     char info_buf[256];
     PaStreamParameters pa_params;
 
-    int sr[] = { 8000, 11025, 12000, 16000, 22050, 24000, 32000, 44100, 48000};
+    int sr[] = {8000, 11025, 12000, 16000, 22050, 24000, 32000, 44100, 48000};
 
     snd_dev_t **dev_list;
+    dev_list = (snd_dev_t**)malloc(SND_MAX_DEVICES*sizeof(snd_dev_t*));
 
-
-    dev_list = (snd_dev_t**)malloc(100*sizeof(snd_dev_t*));
-
-	//100 sound devices should be enough
-    for(i = 0; i < 100; i++)
+    for(i = 0; i < SND_MAX_DEVICES; i++)
         dev_list[i] = (snd_dev_t*)malloc(sizeof(snd_dev_t));
 
     dev_list[0]->name = (char*) malloc(strlen(_("Default PCM device (default)"))+1);
@@ -753,15 +804,14 @@ snd_dev_t **snd_get_devices(int *dev_count)
     
     dev_num = 1;
 
-
-    devcount = Pa_GetDeviceCount();
-    if(devcount < 0)
+    available_devices = Pa_GetDeviceCount();
+    if(available_devices < 0)
     {
-        snprintf(info_buf, sizeof(info_buf), "PaError: %s", Pa_GetErrorText(devcount));
+        snprintf(info_buf, sizeof(info_buf), "PaError: %s", Pa_GetErrorText(available_devices));
         print_info(info_buf, 1);
     }
 
-    for(i = 0; i < devcount && i < 100; i++)
+    for(i = 0; i < available_devices && i < SND_MAX_DEVICES-1; i++)
     {
         sr_count = 0;
         p_di = Pa_GetDeviceInfo(i);
@@ -777,7 +827,6 @@ snd_dev_t **snd_get_devices(int *dev_count)
         if(p_di->maxInputChannels <= 0)
             continue;
         
-
         const PaHostApiInfo *pa_hostapi = Pa_GetHostApiInfo(p_di->hostApi);
         pa_params.device = i;
         pa_params.channelCount = p_di->maxInputChannels;
@@ -807,7 +856,7 @@ snd_dev_t **snd_get_devices(int *dev_count)
         dev_list[dev_num]->name = (char*) malloc(strlen(p_di->name)+strlen(pa_hostapi->name)+10);
         dev_list[dev_num]->dev_id = i;
         dev_list[dev_num]->num_of_channels = p_di->maxInputChannels;
-        snprintf(dev_list[dev_num]->name, strlen(p_di->name)+strlen(pa_hostapi->name)+10, "%d: %s [%s]", dev_num, p_di->name, pa_hostapi->name);
+        snprintf(dev_list[dev_num]->name, strlen(p_di->name)+strlen(pa_hostapi->name)+10, "%s [%s]", p_di->name, pa_hostapi->name);
 
 
         //copy the sr_list from the device where the
@@ -881,7 +930,7 @@ char *snd_get_device_name(int id)
     if(pa_dev_info == NULL)
         return NULL;
     else
-        return strdup(pa_dev_info->name); // Make sure it will be free'd on the caller side
+        return strdup(pa_dev_info->name); // Note: Make sure it will be free'd on the caller side
 }
 
 int snd_get_number_of_channels(int id)
@@ -895,6 +944,20 @@ int snd_get_number_of_channels(int id)
         return pa_dev_info->maxInputChannels;
 }
 
+int snd_get_dev_num_by_name(char *name)
+{
+    if (name != NULL)
+    {
+        for (int i = 0; i < cfg.audio.dev_count; i++)
+        {
+            if (!strcmp(name, cfg.audio.pcm_list[i]->name))
+                return i;
+        }
+    }
+    
+    return -1; // Device not found
+}
+
 void snd_close(void)
 {
     Pa_StopStream(stream);
@@ -909,6 +972,9 @@ void snd_close(void)
 
     free(pa_pcm_buf);
     free(encode_buf);
+
+    rb_free(&rec_rb);
+    rb_free(&stream_rb);
 }
 
 
