@@ -23,6 +23,8 @@
 
 #include "lame_encode.h"
 
+#define SND_MAX_DEVICES (256)
+
 typedef struct
 {
     char *name;
@@ -30,7 +32,7 @@ typedef struct
     int sr_list[10]; //8000, 11025, 12000, 16000, 22050, 24000, 32000, 44100, 48000, 0
     int num_of_sr;
     int num_of_channels;
-    int left_ch; //<- implementieren
+    int left_ch;
     int right_ch;
 }snd_dev_t;
 
@@ -50,6 +52,7 @@ extern bool signal_detected;
 extern FILE *next_fd;
 
 int *snd_get_samplerates(int *sr_count);
+void snd_free_device_list(void);
 snd_dev_t **snd_get_devices(int *dev_count);
 void *snd_rec_thread(void *data);
 void *snd_stream_thread(void *data);
@@ -73,5 +76,9 @@ int snd_callback(const void *input,
                  const PaStreamCallbackTimeInfo* timeInfo,
                  PaStreamCallbackFlags statusFlags,
                  void *userData);
+
+void snd_reset_compressor();
+int snd_get_dev_num_by_name(char *name);
+
 #endif
 
