@@ -20,6 +20,7 @@
 
 #ifdef WIN32
  #include <winsock2.h>
+ #include <Ws2tcpip.h>
  #ifndef errno 
   #define errno WSAGetLastError() 
  #endif
@@ -42,55 +43,75 @@
  typedef int socklen_t;
 #endif
 
-
-int sock_connect(const char *addr, short port, int timout_ms)
+void sock_init(void)
 {
-    int sock;
-    struct hostent *host_ptr;
-    struct sockaddr_in hostname;
-
 #ifdef WIN32
     WSADATA wsa;
     WSAStartup(MAKEWORD(2,2),&wsa);
 #endif
-
-    sock = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP);
-    if(sock == -1)
-          return SOCK_ERR_CREATE;
-
-    host_ptr = gethostbyname(addr);
-    if(host_ptr == NULL)
+}
+int sock_connect(const char *addr, unsigned int port, int timout_ms)
+{
+    int sock;
+    int ret;
+    char port_str[8];
+    struct addrinfo hints, *infoptr, *p; // So no need to use memset global variables
+    
+    snprintf(port_str, sizeof(port_str), "%d", port);
+    memset(&hints, 0, sizeof hints);
+    hints.ai_family = AF_UNSPEC;
+    hints.ai_socktype = SOCK_STREAM;
+    
+    if (getaddrinfo(addr, port_str, &hints, &infoptr) != 0)
     {
-        host_ptr = gethostbyaddr(addr, strlen(addr), AF_INET);
-        if(host_ptr == NULL)
-        {
+        return SOCK_ERR_RESOLVE;
+    }
+    
+    for (p = infoptr; p != NULL; p = p->ai_next)
+    {
+        sock = socket(p->ai_family, p->ai_socktype, p->ai_protocol);
+        if (sock == -1) {
+            continue;
+        }
+        
+        ret = connect(sock, p->ai_addr, p->ai_addrlen);
+        if (ret == -1) {
             sock_close(sock);
-            return SOCK_ERR_RESOLVE;
+            continue;
         }
+        
+        break;
+    }
+    
+    if (sock == -1)
+    {
+        freeaddrinfo(infoptr);
+        return SOCK_ERR_CREATE;
+    }
+    
+    if (ret == -1)
+    {
+        freeaddrinfo(infoptr);
+        return SOCK_TIMEOUT;
     }
-
-    hostname.sin_family = AF_INET;
-    hostname.sin_port = htons(port);
-
-    memcpy(&hostname.sin_addr, host_ptr->h_addr, host_ptr->h_length);
-
     
     sock_nonblock(sock);
-
-    connect(sock, (struct sockaddr*) &hostname, sizeof(hostname));
-
     if(sock_select(sock, timout_ms, WRITE) <= 0)
     {
         sock_close(sock);
+        freeaddrinfo(infoptr);
         return SOCK_TIMEOUT;
     }
+   
 
     if(!sock_isvalid(sock))
     {
         sock_close(sock);
+        freeaddrinfo(infoptr);
         return SOCK_INVALID;
     }
 
+    freeaddrinfo(infoptr);
     return sock;
 }
 
@@ -233,18 +254,53 @@ int sock_isvalid(int s)
     getsockopt(s, SOL_SOCKET, SO_ERROR, (char*)(&optval), &len);
     
 
-
     if (optval)
         return 0;
 
     return 1;
 }
 
+int sock_listen(int port, int *listen_sock)
+{
+    int conn_sock;
+    int val = 1;
+
+    struct sockaddr_in servaddr;
+  
+    *listen_sock = socket(AF_INET, SOCK_STREAM, 0);
+    if(*listen_sock == -1) {
+          return SOCK_ERR_CREATE;
+    }
+
+    memset(&servaddr, 0, sizeof(servaddr));
+    servaddr.sin_family = AF_INET;
+    servaddr.sin_addr.s_addr = htonl(INADDR_ANY);
+    servaddr.sin_port = htons(port);
+      
+    // Make sure the port can be re-used without waiting for the TIME_WAIT period is over
+    //(https://stackoverflow.com/questions/3229860/what-is-the-meaning-of-so-reuseaddr-setsockopt-option-linux)
+    setsockopt(*listen_sock, SOL_SOCKET, SO_REUSEADDR, (const char*)&val, sizeof(int));
+
+    if (bind(*listen_sock, (struct sockaddr*)&servaddr, sizeof(servaddr)) != 0) {
+        return SOCK_ERR_BIND;
+    }
+    
+    if ((listen(*listen_sock, 1)) != 0) {
+        return SOCK_ERR_LISTEN;
+    }
+
+    conn_sock = accept(*listen_sock, NULL, NULL);
+    
+    if (conn_sock >= 0)
+        sock_close(*listen_sock);
+
+    return conn_sock;
+}
+
 void sock_close(int s)
 {
 #ifdef WIN32
     closesocket(s);
-    WSACleanup();
 #else
     close(s);
 #endif
